#
# spec file for package openvswitch
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
%define lname libopenvswitch-2_8-0
%ifarch aarch64 x86_64 %{ix86}
%if 0%{?sle_version} || 0%{?suse_version}
# DPDK enabled only SUSE/openSUSE
%bcond_without dpdk
%else
# DPDK disabled elsewhere even if supported by the architecture.
%bcond_with dpdk
%endif
%else
# No DPDK support on these architectures
%bcond_with dpdk
%endif
# The testsuite is somewhat fragile for continuous testing in OBS
# but keep it here as an option
%bcond_with check
# Disable building the external kernel datapath by default
%bcond_with kmp
Name:           openvswitch
Version:        2.8.7
Release:        lp150.5.14.1
Summary:        A multilayer virtual network switch
# All code is Apache-2.0 except
# - lib/sflow* which is SISSL
# - utilities/bugtool which is LGPL-2.1
License:        Apache-2.0 AND LGPL-2.1-only AND SISSL
Group:          Productivity/Networking/System
Url:            http://openvswitch.org/
Source0:        http://openvswitch.org/releases/openvswitch-%{version}.tar.gz
Source1:        preamble
Source89:       Module.supported.updates
# PATCH-FIX-UPSTREAM: 0002-netdev-dpdk-DPDK-v17.11-upgrade.patch
Patch0:         0002-netdev-dpdk-DPDK-v17.11-upgrade.patch
# PATCH-FIX-UPSTREAM: 0003-netdev-dpdk-vHost-IOMMU-support.patch
Patch1:         0003-netdev-dpdk-vHost-IOMMU-support.patch
# PATCH-FIX-UPSTREAM: 0001-rhel-don-t-drop-capabilities-when-running-as-root.patch (bsc#1128407)
Patch2:         0001-rhel-don-t-drop-capabilities-when-running-as-root.patch
# PATCH-FIX-UPSTREAM: 0002-rhel-Fix-literal-dollar-sign-usage-in-systemd-servic.patch (bsc#1128407)
Patch3:         0002-rhel-Fix-literal-dollar-sign-usage-in-systemd-servic.patch
# PATCH-FIX-UPSTREAM: 0003-rhel-Use-correct-user-in-the-logrotate-configuration.patch (bsc#1104049)
Patch4:         0003-rhel-Use-correct-user-in-the-logrotate-configuration.patch
Patch99:        0001-utilities-Add-script-to-support-DPDK-option-migratio.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  graphviz
BuildRequires:  libcap-ng-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)
Requires:       modutils
# ovs-ctl / ovs-pki use /usr/bin/uuidgen:
Requires:       util-linux
Provides:       openvswitch-common = %{version}
Obsoletes:      openvswitch-common < 2.7.0
Provides:       openvswitch-controller = %{version}
Obsoletes:      openvswitch-controller < 2.7.0
# openvswitch-switch has been merged to the main package
# so we need to provide a migration path
Provides:       %{name}-dpdk = %{version}
Provides:       %{name}-dpdk-switch = %{version}
Provides:       %{name}-switch = %{version}
Obsoletes:      %{name}-dpdk < 2.7.0
Obsoletes:      %{name}-dpdk-switch < 2.7.0
Obsoletes:      %{name}-switch < 2.7.0
%if 0%{?sle_version} || 0%{?suse_version}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module xml}
BuildRequires:  fdupes
BuildRequires:  libopenssl-devel
BuildRequires:  python-rpm-macros
Requires(post): %fillup_prereq
Requires(pre):  shadow
Suggests:       logrotate
%{?systemd_requires}
%else
BuildRequires:  findutils
BuildRequires:  openssl-devel
BuildRequires:  python-devel
BuildRequires:  python-six
BuildRequires:  python2-rpm-macros
BuildRequires:  python2-setuptools
BuildRequires:  python3-rpm-macros
BuildRequires:  systemd-units
Requires(post): systemd-units
Requires(postun): systemd-units
Requires(pre):  shadow-utils
Requires(preun): systemd-units
%endif
# Needed by the testsuite
%if %{with check}
BuildRequires:  procps
%endif
%if %{with kmp}
Suggests:       openvswitch-kmp
%endif
%if %{with dpdk}
# We need to be a bit strict with the dpdk version since
# it's very possible for DPDK to change it's API between
# releases. This version currently requires >=17.XX
BuildRequires:  dpdk-devel >= 17.05
BuildRequires:  libnuma-devel
BuildRequires:  libpcap-devel
%endif

%description
Open vSwitch is a multilayer virtual network Ethernet switch. It is
enables network automation through programmatic extension, and
supports standard management interfaces and protocols (e.g. NetFlow,
sFlow, RSPAN, ERSPAN, CLI, LACP, 802.1ag). In addition, it supports
distribution across multiple physical servers similar to VMware’s
vNetwork distributed vswitch or Cisco’s Nexus 1000V.

%if %{with kmp}
%package kmp
Summary:        Open vSwitch kernel modules
License:        GPL-2.0-or-later
Group:          System/Kernel
BuildRequires:  %{kernel_module_package_buildreqs}
%suse_kernel_module_package -p %{_sourcedir}/preamble ec2 xenpae vmi um

%description kmp
Kernel modules supporting the openvswitch datapath.
%endif

%package -n %{lname}
Summary:        Open vSwitch core libraries
License:        Apache-2.0
Group:          System/Libraries

%description -n %{lname}
Contains the shared libraries used by Open vSwitch and any eventual extensions.

%package doc
Summary:        Open vSwitch Documentation
License:        Apache-2.0
Group:          System/Libraries
BuildArch:      noarch

%description doc
Contains additional documentation for the Open vSwitch

%package devel
Summary:        Development files for Open vSwitch
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Provides:       %{name}-dpdk-devel = %{version}
Obsoletes:      %{name}-dpdk-devel < 2.7.0

%description devel
Devel libraries and headers for Open vSwitch.

%package ovn-central
Summary:        Open Virtual Network support for Open vSwitch
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Requires:       %{name}-ovn-common
# openvswitch-ovn has been split into openvswitch-ovn-{central,common,docker,host,vtep}
Provides:       %{name}-dpdk-ovn:%{_bindir}/ovn-northd
Provides:       %{name}-ovn:%{_bindir}/ovn-northd

%description ovn-central
OVN, the Open Virtual Network, is a system to support virtual network
abstraction.  OVN complements the existing capabilities of OVS to add
native support for virtual network abstractions, such as virtual L2 and L3
overlays and security groups.

%package ovn-host
Summary:        Open Virtual Network support for Open vSwitch
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Requires:       %{name}-ovn-common
# openvswitch-ovn has been split into openvswitch-ovn-{central,common,docker,host,vtep}
Provides:       %{name}-dpdk-ovn:%{_bindir}/ovn-controller
Provides:       %{name}-ovn:%{_bindir}/ovn-controller

%description ovn-host
This subpackage contains the OVN host controller.

%package ovn-vtep
Summary:        Open Virtual Network VTEP controller for Open vSwitch
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Requires:       %{name}-ovn-common
# openvswitch-ovn has been split into openvswitch-ovn-{central,common,docker,host,vtep}
Provides:       %{name}-dpdk-ovn:%{_bindir}/ovn-controller-vtep
Provides:       %{name}-ovn:%{_bindir}/ovn-controller-vtep

%description ovn-vtep
This subpackage contains the OVN VTEP (VXLAN Tunnel Endpoint) controller.

%package ovn-common
Summary:        Open Virtual Network diagnostic utilities
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
# openvswitch-ovn has been split into openvswitch-ovn-{central,common,docker,host,vtep}
Provides:       %{name}-dpdk-ovn = %{version}
Provides:       %{name}-ovn = %{version}
Obsoletes:      %{name}-dpdk-ovn < 2.7.0
Obsoletes:      %{name}-ovn < 2.7.0

%description ovn-common
Utilities that are used to diagnose and manage the OVN components.

%package ovn-docker
Summary:        Docker network plugins for OVN
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Requires:       %{name}-ovn-common = %{version}
Requires:       python-openvswitch = %{version}
# openvswitch-ovn has been split into openvswitch-ovn-{central,common,docker,host,vtep}
Provides:       %{name}-dpdk-ovn:%{_bindir}/ovn-docker-overlay-driver
Provides:       %{name}-ovn:%{_bindir}/ovn-docker-overlay-driver

%description ovn-docker
Docker network plugins for OVN.

%package pki
Summary:        Open vSwitch public key infrastructure dependency package
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Provides:       %{name}-dpdk-pki = %{version}
Obsoletes:      %{name}-dpdk-pki < 2.7.0

%description pki
openvswitch-pki provides PKI (public key infrastructure) support for
Open vSwitch switches and controllers, reducing the risk of
man-in-the-middle attacks on the Open vSwitch network infrastructure.

Open vSwitch is a full-featured software-based Ethernet switch.

%package vtep
Summary:        Open vSwitch VTEP emulator
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Requires:       %{name}-switch = %{version}
# Since openvswitch/scripts/ovs-vtep requires various ovs python modules.
Requires:       python-openvswitch = %{version}
Provides:       %{name}-dpdk-vtep = %{version}
Obsoletes:      %{name}-dpdk-vtep < 2.7.0

%description vtep
A VTEP (VXLAN Tunnel EndPoint) emulator that uses Open vSwitch for
forwarding.

Open vSwitch is a full-featured software-based Ethernet switch.

%package -n python2-ovs
Summary:        Python2 bindings for Open vSwitch
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{lname} = %{version}
Requires:       python2
Requires:       python2-six
Provides:       python-%{name} = %{version}
Provides:       python2-%{name} = %{version}
Obsoletes:      python-%{name} < 2.8.1
Obsoletes:      python2-%{name} < 2.8.5

%description -n python2-ovs
This package contains the Python2 bindings for Open vSwitch database.

%package -n python3-ovs
Summary:        Python3 bindings for Open vSwitch
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{lname} = %{version}
Requires:       python3
Requires:       python3-six
Provides:       python3-%{name} = %{version}
Obsoletes:      python3-%{name} < 2.8.5

%description -n python3-ovs
This package contains the Python3 bindings for Open vSwitch database.

%package test
Summary:        Open vSwitch test package
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Requires:       python2
Requires:       python2-Twisted
Requires:       python2-ovs = %{version}
Provides:       %{name}-dpdk-test = %{version}
Provides:       python-%{name}-test = %{version}
Provides:       python2-%{name}-test = %{version}
Obsoletes:      %{name}-dpdk-test < 2.7.0
Obsoletes:      python-%{name}-test < 2.8.1
Obsoletes:      python2-%{name}-test <= 2.8.5

%description test
Open vSwitch is a software-based Ethernet switch.

This package contains utilities that are useful to diagnose
performance and connectivity issues in Open vSwitch setup.

%prep
%setup -q -n openvswitch-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch99 -p1

%build
set -- * .travis* .mailmap
mkdir source
mv "$@" source/
mkdir obj

pushd source
# only call boot.sh for distros with autoconf >= 2.64
bash -x boot.sh
popd
%if %{with kmp}
    export EXTRA_CFLAGS='-DVERSION=\"%{version}\"'
    for flavor in %{flavors_to_build}; do
        rm -rf obj/$flavor
        cp -r source obj/$flavor
        cp -a %{SOURCE89} obj/$flavor/datapath/linux/Module.supported
        pushd obj/$flavor
        %configure \
            --with-logdir=%{_localstatedir}/log/openvswitch \
            --with-rundir=%{_rundir}/openvswitch \
            --with-linux=%{_prefix}/src/linux-obj/%{_target_cpu}/$flavor \
            --with-linux-source=%{_prefix}/src/linux
        cd datapath/linux
        make %{?_smp_mflags}
        popd
    done
%endif

pushd source

%if %{with dpdk}
    dpdk_opt="--with-dpdk"
%endif

%{_bindir}/perl build-aux/dpdkstrip.pl \
%if %{with dpdk}
    --dpdk \
%else
    --nodpdk \
%endif
    < rhel/usr_lib_systemd_system_ovs-vswitchd.service.in \
    > rhel/usr_lib_systemd_system_ovs-vswitchd.service

# This is only used for building the ovstest module
export PYTHON='%{_bindir}/python2'

%configure \
        --disable-static \
        --enable-libcapng \
        --enable-shared \
        --enable-ssl \
        ${dpdk_opt} \
        --with-rundir=%{_rundir}/openvswitch \
        --with-logdir=%{_localstatedir}/log/openvswitch
make %{?_smp_mflags}
popd

%check
%if %{with check}
pushd source
# Recheck tests before we declare them broken. If that fails, dump
# the log and exit. >2.5.0 uses the RECHECK env variable so this
# needs to be taken into consideration for future releases.
if ! make check TESTSUITEFLAGS="%{?_smp_mflags}" &&
   ! make check TESTSUITEFLAGS='--recheck'; then
    cat tests/testsuite.log
    exit 1
fi
popd
%endif

%install
%if %{with kmp}
export NO_BRP_STALE_LINK_ERROR=yes
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=updates
export BRP_PESIGN_FILES="*.ko /lib/firmware"
for flavor in %{flavors_to_build}; do
    pushd obj/$flavor/datapath/linux
    make -C %{_prefix}/src/linux-obj/%{_target_cpu}/$flavor modules_install M=$PWD
    popd
done
%endif

pushd source

%make_install

# Install extra headers not included with 'make install'
for header in $(find lib -type f -name "*.h"); do
        install -d -m 755 %{buildroot}%{_includedir}/%{name}/"$(dirname $header)"
        install -m 644 "$header" %{buildroot}%{_includedir}/%{name}/"$(dirname $header)"
done

for service in openvswitch ovn-controller ovn-controller-vtep \
    ovn-northd ovsdb-server ovs-vswitchd; do
        install -D -m 644 rhel/usr_lib_systemd_system_${service}.service \
        %{buildroot}%{_unitdir}/${service}.service
        ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc${service}
done

%if %{with dpdk}
    install -p -D -m 0644 rhel/usr_lib_udev_rules.d_91-vfio.rules \
    %{buildroot}%{_prefix}/lib/udev/rules.d/91-vfio.rules
%endif

%if 0%{?sle_version} || 0%{?suse_version}
install -D -m 644 rhel/usr_share_openvswitch_scripts_systemd_sysconfig.template \
        %{buildroot}%{_fillupdir}/sysconfig.openvswitch
%else
install -D -m 644 rhel/usr_share_openvswitch_scripts_systemd_sysconfig.template \
        %{buildroot}%{_sysconfdir}/sysconfig/openvswitch
install -d -m 0755 %{buildroot}/%{_sysconfdir}/sysconfig/network-scripts/
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifdown-ovs \
        %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifup-ovs \
        %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%endif

install -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
install -d -m 755 %{buildroot}%{_localstatedir}/log/openvswitch

install -p -D -m 0644 rhel/etc_openvswitch_default.conf \
         %{buildroot}/%{_sysconfdir}/openvswitch/default.conf
install -m 644 rhel/etc_logrotate.d_openvswitch \
         %{buildroot}%{_sysconfdir}/logrotate.d/openvswitch
install -d -m 755 %{buildroot}%{_sysconfdir}/profile.d

install -m 644 vswitchd/vswitch.ovsschema \
         %{buildroot}%{_datadir}/openvswitch/vswitch.ovsschema

# firewalld
install -d %{buildroot}%{_prefix}/lib/firewalld/services/
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-central-firewall-service.xml \
        %{buildroot}%{_prefix}/lib/firewalld/services/ovn-central-firewall-service.xml
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-host-firewall-service.xml \
        %{buildroot}%{_prefix}/lib/firewalld/services/ovn-host-firewall-service.xml

# Copy documentation.
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -r Documentation/* %{buildroot}%{_docdir}/%{name}
find %{buildroot}%{_docdir}/%{name}/ -type f ! -name '*.rst' -delete

# DPDK migration script
install -m 755 utilities/ovs-dpdk-migrate-2.6.sh %{buildroot}/%{_datadir}/openvswitch/scripts/

popd

# Tests
mkdir -p %{buildroot}%{python2_sitelib}
cp -a %{buildroot}%{_datadir}/openvswitch/python/ovstest \
    %{buildroot}%{python2_sitelib}

# Python subpackages
pushd source/python

export LDFLAGS="${LDFLAGS} -L %{buildroot}%{_libdir}"
export CPPFLAGS="-I ../include"

%if 0%{?suse_version}
# SLES
%{python_build}
%{python_install}
%fdupes %{buildroot}%{python2_sitearch}
%fdupes %{buildroot}%{python3_sitearch}

%else
# RHEL
%py2_build
%py2_install
# No python3 for RHEL. We are missing python3-* packages from EPEL
%endif

popd

rm -rf %{buildroot}%{_datadir}/openvswitch/python

find %{buildroot} -type f -name "*.la" -delete -print

%define eflag /run/openvswitch-was-enabled

%post
/sbin/ldconfig
if grep -q ^DPDK_OPTIONS= %{_sysconfdir}/sysconfig/openvswitch &> /dev/null; then
    cat >> %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}-something << EOF
    WARNING! DPDK options are now part of the Open vSwitch database. Please see
    https://github.com/openvswitch/ovs/blob/branch-2.7/Documentation/intro/install/dpdk.rst

    The Open vSwitch systemd service will try to migrate your %{_sysconfdir}/sysconfig/openvswitch
    DPDK settings to the OvS database the next time it's restarted but you should check the result
    using 'ovs-vsctl list Open_vSwitch' or something similar.

    Please remember to remove the DPDK_OPTIONS variable from %{_sysconfdir}/sysconfig/openvswitch
    to avoid seeing this warning again.
EOF
fi

if [ $1 -eq 1 ]; then
    # Follow the upstream strategy that no running openvswitch
    # configuration is changed on upgrade so use fillup only for new installs.
    %if 0%{?sle_version} || 0%{?suse_version}
        %{fillup_only -n openvswitch}
    %endif

%if %{with dpdk}
    %define rgroup hugetlbfs
%else
    %define rgroup openvswitch
%endif

    sed -i \
        's@^#OVS_USER_ID="openvswitch:openvswitch"@OVS_USER_ID="openvswitch:%{rgroup}"@'\
        %{_sysconfdir}/sysconfig/openvswitch
    sed -i 's:\(.*su\).*:\1 openvswitch %{rgroup}:' %{_sysconfdir}/logrotate.d/openvswitch

    # In the case of upgrade, this is not needed
    chown -R openvswitch:openvswitch %{_sysconfdir}/openvswitch
    chown -R openvswitch:%{rgroup} %{_localstatedir}/log/openvswitch
fi
%if 0%{?sle_version} || 0%{?suse_version}
	%service_add_post ovsdb-server.service
	%service_add_post ovs-vswitchd.service
	%service_add_post openvswitch.service
%else
    %if 0%{?systemd_post:1}
        %systemd_post %{name}.service
    %else
        # Package install, not upgrade
        if [ $1 -eq 1 ]; then
            /bin/systemctl daemon-reload >dev/null || :
        fi
    %endif
%endif

%posttrans
# Save the "enabled" state across the transition of ownership
# of openvswitch.service from openvswitch-switch to
# openvswitch.
if test -f %{eflag}; then
    rm -f %{eflag}
    systemctl enable openvswitch.service
fi

%postun
/sbin/ldconfig
# Do not restart the openvswitch service on package updates.
# Restarting the service may break the existing network state.
# For example, openflow rules are not automatically re-installed
# after an OvS update if no SDN controller is used. Moreover, restaring
# the OvS can break remote administration during the update so let the
# admin decide when it's the best time for an OvS restart.
# 5771f476573445710834234a6a9f7bd999a027e7 ("fedora: do not restart the service on a pkg upgrade")
%if 0%{?sle_version} || 0%{?suse_version}
    export DISABLE_RESTART_ON_UPDATE=yes
    %service_del_postun ovsdb-server.service
    %service_del_postun ovs-vswitchd.service
    %service_del_postun openvswitch.service
%else
    %if 0%{?systemd_postun:1}
        %systemd_postun %{name}.service
    %else
        /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    %endif
%endif

%pre
%if 0%{?sle_version} || 0%{?suse_version}
%service_add_pre ovsdb-server.service
%service_add_pre ovs-vswitchd.service
%service_add_pre openvswitch.service
%endif
# Save the "enabled" state across the transition of
# ownership of openvswitch.service from openvswitch-switch to
# openvswitch.
if [ "$FIRST_ARG" -ge 1 ]; then \
    if [ x$(systemctl is-enabled openvswitch.service 2>/dev/null ||:) = "xenabled" ]; then
        touch %{eflag}
    fi
fi

getent group openvswitch >/dev/null || groupadd -r openvswitch
getent passwd openvswitch >/dev/null || \
    useradd -r -g openvswitch -d / -s /sbin/nologin \
    -c "Open vSwitch Daemons" openvswitch

%if %{with dpdk}
    getent group hugetlbfs >/dev/null || \
    groupadd -r hugetlbfs
    usermod -a -G hugetlbfs openvswitch
%endif
exit 0

%preun
# This prevents networking breakages on package removals.
export DISABLE_STOP_ON_REMOVAL=yes
%if 0%{?sle_version} || 0%{?suse_version}
    %service_del_preun ovsdb-server.service
    %service_del_preun ovs-vswitchd.service
    %service_del_preun openvswitch.service
%else
    %if 0%{?systemd_preun:1}
        %systemd_preun %{name}.service
    %else
        # Package install, not upgrade
        if [ $1 -eq 0 ]; then
            /bin/systemctl --no-reload disable %{name}.service >/dev/null 2>&1 || :
            /bin/systemctl stop %{name}.service >/dev/null 2>&1 || :
        fi
    %endif
%endif

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%pre ovn-central
%if 0%{?sle_version} || 0%{?suse_version}
%service_add_pre ovn-northd.service
%endif

%pre ovn-host
%if 0%{?sle_version} || 0%{?suse_version}
%service_add_pre ovn-controller.service
%endif

%pre ovn-vtep
%if 0%{?sle_version} || 0%{?suse_version}
%service_add_pre ovn-controller-vtep.service
%endif

%post ovn-central
%if 0%{?sle_version} || 0%{?suse_version}
    %service_add_post ovn-northd.service
%else
    %if 0%{?systemd_post:1}
        %systemd_post ovn-northd.service
    %else
        # Package install, not upgrade
        if [ $1 -eq 1 ]; then
            /bin/systemctl daemon-reload >dev/null || :
        fi
    %endif
%endif

%post ovn-host
%if 0%{?sle_version} || 0%{?suse_version}
    %service_add_post ovn-controller.service
%else
    %if 0%{?systemd_post:1}
        %systemd_post ovn-controller.service
    %else
        # Package install, not upgrade
        if [ $1 -eq 1 ]; then
            /bin/systemctl daemon-reload >dev/null || :
        fi
    %endif
%endif

%post ovn-vtep
%if 0%{?sle_version} || 0%{?suse_version}
    %service_add_post ovn-controller-vtep.service
%else
    %if 0%{?systemd_post:1}
        %systemd_post ovn-controller-vtep.service
    %else
        # Package install, not upgrade
        if [ $1 -eq 1 ]; then
            /bin/systemctl daemon-reload >dev/null || :
        fi
    %endif
%endif

%preun ovn-central
# This prevents networking breakages on package removals.
export DISABLE_STOP_ON_REMOVAL=yes
%if 0%{?sle_version} || 0%{?suse_version}
    %service_del_preun ovn-northd.service
%else
    %if 0%{?systemd_preun:1}
        %systemd_preun ovn-northd.service
    %else
        # Package install, not upgrade
        if [ $1 -eq 0 ]; then
            /bin/systemctl --no-reload disable ovn-northd.service >/dev/null 2>&1 || :
            /bin/systemctl stop ovn-northd.service >/dev/null 2>&1 || :
        fi
    %endif
%endif

%preun ovn-host
# This prevents networking breakages on package removals.
export DISABLE_STOP_ON_REMOVAL=yes
%if 0%{?sle_version} || 0%{?suse_version}
    %service_del_preun ovn-controller.service
%else
    %if 0%{?systemd_preun:1}
        %systemd_preun ovn-controller.service
    %else
        # Package install, not upgrade
        if [ $1 -eq 0 ]; then
            /bin/systemctl --no-reload disable ovn-controller.service >/dev/null 2>&1 || :
            /bin/systemctl stop ovn-controller.service >/dev/null 2>&1 || :
        fi
    %endif
%endif

%preun ovn-vtep
# This prevents networking breakages on package removals.
export DISABLE_STOP_ON_REMOVAL=yes
%if 0%{?sle_version} || 0%{?suse_version}
    %service_del_preun ovn-controller-vtep.service
%else
    %if 0%{?systemd_preun:1}
        %systemd_preun ovn-controller-vtep.service
    %else
        # Package install, not upgrade
        if [ $1 -eq 0 ]; then
            /bin/systemctl --no-reload disable ovn-controller-vtep.service >/dev/null 2>&1 || :
            /bin/systemctl stop ovn-controller-vtep.service >/dev/null 2>&1 || :
        fi
    %endif
%endif

%postun ovn-central
export DISABLE_RESTART_ON_UPDATE=yes
%if 0%{?sle_version} || 0%{?suse_version}
    %service_del_postun ovn-northd.service
%else
    %if 0%{?systemd_postun:1}
        %systemd_postun ovn-northd.service
    %else
        /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    %endif
%endif

%post ovn-common -p /sbin/ldconfig
%postun ovn-common -p /sbin/ldconfig
%postun ovn-host
export DISABLE_RESTART_ON_UPDATE=yes
%if 0%{?sle_version} || 0%{?suse_version}
    %service_del_postun ovn-controller.service
%else
    %if 0%{?systemd_postun:1}
        %systemd_postun ovn-controller.service
    %else
        /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    %endif
%endif

%postun ovn-vtep
export DISABLE_RESTART_ON_UPDATE=yes
%if 0%{?sle_version} || 0%{?suse_version}
    %service_del_postun ovn-controller-vtep.service
%else
    %if 0%{?systemd_postun:1}
        %systemd_postun ovn-controller-vtep.service
    %else
        /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    %endif
%endif

%preun test
# This prevents networking breakages on package removals.
export DISABLE_STOP_ON_REMOVAL=yes
%if 0%{?sle_version} || 0%{?suse_version}
    %service_del_preun openvswitch-testcontroller
%else
    %if 0%{?systemd_post:1}
        %systemd_preun openvswitch-testcontroller.service
    %else
        # Package install, not upgrade
        if [ $1 -eq 0 ]; then
            /bin/systemctl --no-reload disable openvswitch-testcontroller.service >/dev/null 2>&1 || :
            /bin/systemctl stop openvswitch-testcontroller.service >/dev/null 2>&1 || :
        fi
    %endif
%endif

%postun test
export DISABLE_RESTART_ON_UPDATE=yes
%if 0%{?sle_version} || 0%{?suse_version}
    %service_del_postun openvswitch-testcontroller
%else
    %if 0%{?systemd_postun:1}
        %systemd_postun openvswitch-testcontroller.service
    %else
        /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    %endif
%endif

%post vtep -p /sbin/ldconfig
%postun vtep -p /sbin/ldconfig

%files
%defattr(-,openvswitch,openvswitch)
%dir %{_sysconfdir}/openvswitch
%config(noreplace) %{_sysconfdir}/openvswitch/default.conf
%config %ghost %{_sysconfdir}/openvswitch/conf.db
%ghost %{_sysconfdir}/openvswitch/.conf.db.~lock~
%config %ghost %{_sysconfdir}/openvswitch/system-id.conf
%defattr(-,root,root)
%{_bindir}/ovs-appctl
%{_bindir}/ovs-docker
%{_bindir}/ovs-dpctl
%{_bindir}/ovs-dpctl-top
%{_bindir}/ovs-ofctl
%{_bindir}/ovs-parse-backtrace
%{_bindir}/ovs-vsctl
%{_bindir}/ovsdb-client
%{_bindir}/ovsdb-tool
%{_sbindir}/ovs-bugtool
%{_sbindir}/ovs-vlan-bug-workaround
%{_sbindir}/ovs-vswitchd
%{_sbindir}/ovsdb-server
%dir %{_datadir}/openvswitch
%dir %{_datadir}/openvswitch/scripts
%{_datadir}/openvswitch/bugtool-plugins
%{_datadir}/openvswitch/scripts/ovs-bugtool-*
%{_datadir}/openvswitch/scripts/ovs-check-dead-ifs
%{_datadir}/openvswitch/scripts/ovs-ctl
%{_datadir}/openvswitch/scripts/ovs-lib
%{_datadir}/openvswitch/scripts/ovs-save
%{_datadir}/openvswitch/scripts/ovs-dpdk-migrate-2.6.sh
%{_datadir}/openvswitch/vswitch.ovsschema
%{_mandir}/man1/ovsdb-client.1%{?ext_man}
%{_mandir}/man1/ovsdb-server.1%{?ext_man}
%{_mandir}/man1/ovsdb-tool.1%{?ext_man}
%{_mandir}/man5/ovs-vswitchd.conf.db.5%{?ext_man}
%{_mandir}/man7/ovs-fields.7%{?ext_man}
%{_mandir}/man8/ovs-appctl.8%{?ext_man}
%{_mandir}/man8/ovs-bugtool.8%{?ext_man}
%{_mandir}/man8/ovs-ctl.8%{?ext_man}
%{_mandir}/man8/ovs-dpctl-top.8%{?ext_man}
%{_mandir}/man8/ovs-dpctl.8%{?ext_man}
%{_mandir}/man8/ovs-ofctl.8%{?ext_man}
%{_mandir}/man8/ovs-vlan-bug-workaround.8%{?ext_man}
%{_mandir}/man8/ovs-parse-backtrace.8%{?ext_man}
%{_mandir}/man8/ovs-vsctl.8%{?ext_man}
%{_mandir}/man8/ovs-vswitchd.8%{?ext_man}
%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
%config(noreplace) %{_sysconfdir}/logrotate.d/openvswitch
%{_sbindir}/rcovsdb-server
%{_sbindir}/rcovs-vswitchd
%{_sbindir}/rcopenvswitch
%{_unitdir}/openvswitch.service
%{_unitdir}/ovs-vswitchd.service
%{_unitdir}/ovsdb-server.service
%if 0%{?sle_version} || 0%{?suse_version}
%{_fillupdir}/sysconfig.openvswitch
%else
%config(noreplace) %{_sysconfdir}/sysconfig/openvswitch
%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
%endif
%attr(750,root,root) %dir %{_localstatedir}/log/openvswitch
%ghost %attr(755,root,root) %{_rundir}/openvswitch
%if %{with dpdk}
%{_prefix}/lib/udev/rules.d/91-vfio.rules
%endif

%files doc
%exclude %{_docdir}/%{name}/AUTHORS.rst
%exclude %{_docdir}/%{name}/CONTRIBUTING.rst
%exclude %{_docdir}/%{name}/COPYING
%exclude %{_docdir}/%{name}/NEWS
%exclude %{_docdir}/%{name}/NOTICE
%exclude %{_docdir}/%{name}/README.rst
%{_docdir}/%{name}/

%files -n %{lname}
%{_libdir}/libofproto-2*.so.*
%{_libdir}/libopenvswitch-2*.so.*
%{_libdir}/libovsdb-2*.so.*
%{_libdir}/libsflow-2*.so.*
%{_libdir}/libovn-2*.so.*
%{_libdir}/libvtep-2*.so.*

%files pki
%{_mandir}/man8/ovs-pki.8%{?ext_man}
%{_bindir}/ovs-pki

%files vtep
%{_bindir}/vtep-ctl
%{_mandir}/man5/vtep.5%{?ext_man}
%{_mandir}/man8/vtep-ctl.8%{?ext_man}
%{_datadir}/openvswitch/scripts/ovs-vtep
%{_datadir}/openvswitch/vtep.ovsschema

%files -n python2-ovs
%{python2_sitearch}/ovs/
%{python2_sitearch}/ovs-*.egg-info

%if 0%{?suse_version}
%files -n python3-ovs
%{python3_sitearch}/ovs/
%{python3_sitearch}/ovs-*.egg-info
%endif

%files ovn-docker
%{_bindir}/ovn-docker-overlay-driver
%{_bindir}/ovn-docker-underlay-driver

%files ovn-common
%{_bindir}/ovn-nbctl
%{_bindir}/ovn-sbctl
%{_bindir}/ovn-trace
%{_bindir}/ovn-detrace
%{_datadir}/openvswitch/scripts/ovn-ctl
%{_datadir}/openvswitch/scripts/ovndb-servers.ocf
%{_datadir}/openvswitch/scripts/ovn-bugtool-nbctl-show
%{_datadir}/openvswitch/scripts/ovn-bugtool-sbctl-lflow-list
%{_datadir}/openvswitch/scripts/ovn-bugtool-sbctl-show
%{_mandir}/man5/ovn-nb.5%{?ext_man}
%{_mandir}/man5/ovn-sb.5%{?ext_man}
%{_mandir}/man1/ovn-detrace.1%{?ext_man}
%{_mandir}/man7/ovn-architecture.7%{?ext_man}
%{_mandir}/man8/ovn-ctl.8%{?ext_man}
%{_mandir}/man8/ovn-nbctl.8%{?ext_man}
%{_mandir}/man8/ovn-trace.8%{?ext_man}
%{_mandir}/man8/ovn-sbctl.8%{?ext_man}

%files ovn-central
# Can't use libexecdir because it differs between
# RedHat and SUSE and firewalld expects things in /usr/lib
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/services
%{_bindir}/ovn-northd
%{_mandir}/man8/ovn-northd.8%{?ext_man}
%{_datadir}/openvswitch/ovn-nb.ovsschema
%{_datadir}/openvswitch/ovn-sb.ovsschema
%{_unitdir}/ovn-northd.service
%{_sbindir}/rcovn-northd
%{_prefix}/lib/firewalld/services/ovn-central-firewall-service.xml

%files ovn-host
# Can't use libexecdir because it differs between
# RedHat and SUSE and firewalld expects things in /usr/lib
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/services
%{_bindir}/ovn-controller
%{_mandir}/man8/ovn-controller.8%{?ext_man}
%{_unitdir}/ovn-controller.service
%{_sbindir}/rcovn-controller
%{_prefix}/lib/firewalld/services/ovn-host-firewall-service.xml

%files ovn-vtep
%{_bindir}/ovn-controller-vtep
%{_mandir}/man8/ovn-controller-vtep.8%{?ext_man}
%{_unitdir}/ovn-controller-vtep.service
%{_sbindir}/rcovn-controller-vtep

%files test
%{_bindir}/ovs-l3ping
%{_bindir}/ovs-pcap
%{_bindir}/ovs-test
%{_bindir}/ovs-testcontroller
%{_bindir}/ovs-tcpdump
%{_bindir}/ovs-tcpundump
%{_bindir}/ovs-vlan-test
%{_mandir}/man1/ovs-pcap.1%{?ext_man}
%{_mandir}/man1/ovs-tcpundump.1%{?ext_man}
%{_mandir}/man8/ovs-l3ping.8%{?ext_man}
%{_mandir}/man8/ovs-tcpdump.8%{?ext_man}
%{_mandir}/man8/ovs-testcontroller.8%{?ext_man}
%{python2_sitelib}/ovstest/

%files devel
%{_libdir}/libofproto.so
%{_libdir}/libopenvswitch.so
%{_libdir}/libovn.so
%{_libdir}/libovsdb.so
%{_libdir}/libsflow.so
%{_libdir}/libvtep.so
%{_includedir}/openflow/
%{_includedir}/ovn/
%{_includedir}/openvswitch/
%{_libdir}/pkgconfig/*.pc

%changelog
* Mon Apr 29 2019 <jcaamano@suse.com>
- Fix problem preventing new installs to run as non root (bsc#1132029),
  including:
  * Align with upstream so that no running configuration is changed on
    upgrades, specifically to avoid changes on the user Open vSwitch runs
    under.
  * hugetblfs groups is created as systemgroup
- Version bump to bugfix release 2.8.7 (bsc#1130276). Some of the changes are:
  * ofp-group: support to insert bucket with weight value for select type
  * ofproto: fix the bug of bucket counter is not updated
  * netdev-dpdk: Print netdev name for txq mapping.
  * ifupdown.sh: Add missing "--may-exist" option
  * netdev-tc-offloads: Improve log message for icmpv6 offload not supported
  * travis: Stop rsyslog before start.
  * vlog: Better handle syslog handler exceptions.
  * travis: Remove 'sudo' configuration.
  * ovsdb-monitor.at: Use correct perl scripts.
  * rconn: Avoid occasional immediate connection failures.
  * conntrack: Fix L4 csum for V6 extension hdr pkts.
  * packets: Change return type of 'packet_csum_upperlayer6'.
  * ovsdb-client: Fix typo.
  * ofctl: break the loop if ovs_pcap_read returns error
  * Revert "ovs-tcpdump: Fix an undefined variable"
  * dhparams: Fix .c file generation with OpenSSL >= 1.1.1-pre9
  * dhparams: Add pregenerated .c file to the repository.
  * netlink: added check to prevent netlink attribute overflow
  * conntrack: Keep Address Sanitizer happy.
  * lldp: fix string warnings
  * conntrack: Exclude l2 padding in 'conn_key_extract()'.
  * dp-packet: Add 'dp_packet_l3_size()'.
  * monitor: Fix crash when monitor condition adds new columns.
  * dpif-netdev: Add thread safety annotation to sorted_poll_list.
  * acinclude: Drop DPDK_EXTRA_LIB variable.
  * flow: fix a possible memory leak in parse_ct_state
  * ofproto-dpif-trace: Fix for the segmentation fault in ofproto_trace().
  * datapath: Fix IPv6 later frags parsing
  * datapath: Derive IP protocol number for IPv6 later frags
  * datapath: Avoid OOB read when parsing flow nlattrs
  * dpif-netlink: Fix a bug that causes duplicate key error in datapath
  * odp-util: Stop parse odp actions if nlattr is overflow
  * ovs-tcpdump: Fix an undefined variable
  * stt: Fix return code during xmit.
  * ofpbuf: Fix arithmetic error in ofpbuf_insert().
  * odp-util: Fix a bug in parse_odp_push_nsh_action
  * netdev-linux: Fix function argument order in sfq_tc_load().
  * ofproto-dpif-xlate: Account mirrored packets only if the VLAN matches.
  * ofp-actions: Avoid overflow for ofpact_learn_spec->n_bits
  * python: Escape backslashes while formatting logs.
  * docs: Fix table title for VM MQ config in dpdk howto.
  * conntrack: Check all addresses for ephemeral ports.
  * cmap: Fix hashing in cmap_find_protected().
  * python: Catch setsockopt exceptions for TCP stream.
  * conntrack: Skip ephemeral ports fallback for DNAT.
  * rhel: Add 'SYSTEMD_NO_WRAP=yes' in ovs init script for SLES
  * ofproto: Return correct error codes from meter_set.
  * debian: Install correct vtep-ctl.
  * packets: Fix use-after-free error in packet_put_ra_prefix_opt().
  * Windows: Fix broken kernel userspace communication
  * netdev-tc-offloads: Delete ufid tc mapping in the right place
  * dpif-netlink: Fix error behavior in dpif_netlink_port_add__().
  * datapath-windows: Fix invalid reference in Buffermgmt.c
  * netdev-dpdk: Bring link down when NETDEV_UP is not set
  * actions: Enforce a maximum limit for nested action depth
  * bond: Fix LACP fallback to active-backup when recirc is enabled.
  * netdev-dpdk: Fix netdev_dpdk_get_features().
  * ovn-northd: Fix memory leak in free_chassis_queueid().
  * python-c-ext: Fix memory leak in Parser_finish
  * bridge.c: prevent controller connects while flow-restore-wait
  * connmgr: Fix vswitchd abort when a port is added and the controller is down
  * odp-util: Move ufid handling to odp_flow_from_string
- Remove patches present in upstream 2.8.7:
  * 0001-python-c-ext-Fix-memory-leak-in-Parser_finish.patch
* Mon Mar 25 2019 <jcaamano@suse.com>
- Backport upstream fixes (bsc#1128407)
  * 0001-rhel-don-t-drop-capabilities-when-running-as-root.patch
  * 0002-rhel-Fix-literal-dollar-sign-usage-in-systemd-servic.patch
- Rebased upstream fixes that had conflict with the previous ones
  * 0003-rhel-Use-correct-user-in-the-logrotate-configuration.patch
- Add extra openvswitch headers (bsc#1125897)
* Fri Feb 15 2019 jcaamano@suse.com
- Obsolete old python[2]-openvswitch-test subpackages (bsc#1124435)
* Mon Dec 17 2018 jcaamano@suse.com
- Backport upstream fix for python json parser memory leak (bsc#1116437)
  * 0001-python-c-ext-Fix-memory-leak-in-Parser_finish.patch
* Thu Nov  8 2018 Markos Chandras <mchandras@suse.de>
- Improve python packaging (bsc#1115085)
  * Rename python*-openvswitch subpackages to python*-ovs to follow
    the openSUSE policy that packages should be named after the modules
    they install.
  * Build the JSON C bindings and as a result the 'noarch' BuildArch
    needs to be removed.
  * Drop the python*-openvswitch-test packages and merge them with the
    test subpackage
  * Build the python bindings using setuptools
  * Include the egg-info package.
  * Use libopenvswitch as dependency to python bindings
* Mon Oct 22 2018 Markos Chandras <mchandras@suse.de>
- Version bump to 2.8.5 (bsc#1112703). Some of the changes are:
  * dpif-netdev.at: Add missing backslash.
  * ofproto-dpif-xlate: Avoid deadlock on multicast snooping recursion.
  * expr: Disallow < <= >= > comparisons against empty value set.
  * expr: Set a limit on the depth of nested parentheses
  * dpif-netdev: Add vlan to mask for flow_put operation.
  * odp-util: Fix a use-after-free bug.
  * dpif-netlink: Fix null pointer.
  * dpif-netlink: don't allocate per thread netlink sockets (bsc#1110865)
  * netdev: Properly clear 'details' when iterating in NETDEV_QOS_FOR_EACH.
  * lex: Fix buffer overrun parsing overlong hexadecimal constants.
  * ovsdb-client: Fix a bug that uses wrong index
  * ofproto-dpif-xlate: Fix conntrack fields on NXT_RESUME
  * flow: Fix uninitialized flow fields in IPv6 error case.
  * ofproto-dpif: Fix NXT_RESUME flow stats
  * meta-flow: Make "nw_frag" a synonym for "ip_frag".
  * lib/tc: treat vlan id and prio as independent fields
  * odp-util: Don't attempt to write IPv6 flow label bits that don't exist.
  * lib/tc: reject offloading of non-Ethernet packets
  * ovn-controller: Fix test - IP relocation using GARP request.
  * tests: Make test result more predictable.
  * ovs-ctl: Allow add-remote without vswitchd started.
  * daemon-unix: Use same name for original or restarted children.
  * dpif-netdev: Prevent unsafe access when retrieving meter stats.
  * tests: Use the default key length when generating RSA keys
  * utilities: Drop shebang from bash completion script
  * ofp-actions: Re-fix error path for parsing OpenFlow actions.
  * nx-match: Avoid double-free on some error paths.
  * ovn-northd: Support learning neighbor from ARP request.
  * ovn-northd: LR respond ARP from valid subnet only.
  * netdev-dpdk: Support the link speed of XL710
  * netdev-linux: Avoid division by 0 if kernel reports bad scheduler data.
  * ofp-actions: Avoid assertion failure for clone(ct(...bad actions...)).
  * ovsdb-idl.c: Fix IDL index problem when rows are updated.
  * netdev-dpdk: Fix failure to configure flow control at netdev-init.
  * netdev-dpdk: Use hex for PCI vendor ID.
  * ofctl: Fixup compare_flows function
  * stream-ssl: Define SSL_OP_NO_SSL_MASK for OpenSSL versions that lack it.
  * utilities: Launch ovsdb-tool without using PAM
  * ovs-ofctl: Better validate OpenFlow message length in "ofp-parse-pcap".
  * stream-ssl: Don't enable new TLS versions by default
  * pcap-file: Fix formatting of log message.
  * meta-flow: Make mf_vl_mff_mf_from_nxm_header() require a valid field.
  * nx-match: Fix memory leak in oxm_pull_field_array() error case.
  * compat: Initialize IPv4 reassembly secret timer
  * conntrack: Fix use after free for FTP control case.
  * ifupdown.sh: Correctly bring up bond slaves.
  * conntrack: Fix using alg_exp_entry out of scope.
  * ofp-group: Don't assert-fail decoding bad OF1.5 group mod type or command.
  * ofp-actions: Fix buffer overread in decode_LEARN_specs().
  * ofp-actions: Avoid buffer overread in BUNDLE action decoding.
  * rconn: Suppress 'connected' log for unreliable connections.
  * datapath: stt: linearize in SKIP_ZERO_COPY case
  * ovn: Fix DHCP classless static route for non-classful masks.
  * ofproto: Fix OVS crash when reverting old flows in bundle commit
  * rconn: Introduce new invariant to fix assertion failure in corner case.
  * dpctl.man: Correct argument to "dump-flows".
  * ovs-thread: Fix thread id for threads not started with ovs_thread_create()
  * netdev-dpdk: Handle ENOTSUP for rte_eth_dev_set_mtu.
  * netdev-dpdk: Enable HW_CRC_STRIP for virtual functions.
  * lib: fix typo in fragment handling error messages
- Remove old patch which is included in this release:
  * 0001-utilities-Launch-ovsdb-tool-without-using-PAM.patch
* Thu Aug  9 2018 mchandras@suse.de
- Add upstream patch to fix permissions when running the logrotate
  script (bsc#1104049)
  * 0001-rhel-Use-correct-user-in-the-logrotate-configuration.patch
* Tue Aug  7 2018 mchandras@suse.de
- Add upstream patch to fix dbus timeout due to deadlock in systemd
  dependencies (bsc#1098630).
  * 0001-utilities-Launch-ovsdb-tool-without-using-PAM.patch
* Tue May 29 2018 mchandras@suse.de
- Version bump to 2.8.4 (bsc#1094234). Some of the changes are
  * dpif-netdev: Free packets on TUNNEL_PUSH if may_steal.
  * netdev-dpdk: fix check for "net_nfp" driver
  * netdev-dpdk: Don't use PMD driver if not configured successfully
  * netdev-dpdk: Remove use of rte_mempool_ops_get_count.
  * conntrack-tcp: Handle tcp session reuse.
  * tunnel: make tun_key_to_attr aware of tunnel type.
  * Configurable Link State Change (LSC) detection mode
  * netdev-dpdk: don't enable scatter for jumbo RX support for nfp
  * faq: Document DPDK version maintenance.
  * Avoid crash in OvS while transmitting fragmented packets over tunnel.
  * compat: Fix upstream 4.4.119 kernel
  * ovs-vsctl: Fix segfault when attempting to del-port from parent bridge.
  * ofproto-dpif-xlate: Fix segmentation fault caused by tun_table
  * odp-util: Remove unnecessary TOS ECN bits rewrite for tunnels
  * datapath: Prevent panic
  * netdev-dpdk: Free mempool only when no in-use mbufs.
  * python: Fix a double encoding attempt on an Unicode string
  * ofproto-dpif: Init ukey->dump_seq to zero
  * nsh: Add unit test for double NSH encap and decap
  * xlate: Correct handling of double encap() actions
  * tc: Change filter error to debug once
  * lib/tc: Handle error parsing action in nl_parse_single_action
  * ovn: Fix tunnel id overflow.
  * ofp-actions: Correct execution of encap/decap actions in action set
  * ovsdb-idl.at: Fix test failed. (writing large data via IDL with unicode)
  * netdev-dpdk: Limit rate of DPDK logs.
  * netdev-dpdk: Remove 'error' from non error log.
  * odp-util: Print eth() for Ethernet flows if packet_type is absent.
  * python: Fix decoding error when the received data is larger than 4096.
  * datapath-windows: fix hash creation on ct mark
  * tunnel: Fix deletion of datapath tunnel ports in case of reconfiguration
  * tests: Make packet-type-aware.at hash independent
- Remove patches which are now upstream:
  * 0001-ovsdb-Use-items-instead-of-iteritems-for-Python3.patch
  * 0002-ovsdb-ovsdb-dot.in-Use-print-function-for-Python3.patch
  * 0003-ovsdb-ovsdb-dot.in-Change-exception-semantics-for-Py.patch
  * 0004-ovsdb-ovsdb-dot.in-Replace-sys.maxint-with-sys.maxsi.patch
- Use openvswitch user/group for the log directory (3f556d66edb9)
* Wed May  9 2018 mchandras@suse.de
- Add support for RedHat distributions. All SUSE macros are now
  conditional and the spec file has been adapted based on the upstream
  one (fate#324537)
- spec-cleaner fixes
* Wed May  2 2018 mchandras@suse.de
- Move openvswitch user/group creation to %%pre scriptlet. The default
  ownership of the configuration files expects the user and group to
  be available as early as possible (bsc#1091408)
* Mon Apr 23 2018 mchandras@suse.de
- Preserve 'enable' status of openvswitch.service file when upgrading
  from <SLE-12-SP3. The service file has been moved from the old
  openvswitch-switch subpackage to the main openvswitch one so we
  need to handle this migration step in %%posttrans (bsc#1089476)
- Move DISABLE_STOP_ON_REMOVAL=yes to %%preun. This variable is only
  checked in %%service_del_preun macro
* Thu Mar 22 2018 mchandras@suse.de
- Fix file permissions in /etc/openvswitch for upgrades (951d79e638ec)
* Wed Mar 21 2018 dmueller@suse.com
- set rundir to %%_rundir
* Thu Feb 22 2018 mchandras@suse.de
- Fix incorrect python3 dependencies for python2 subpackages
- Add upstream patches so we can build tools using python3 (bsc#1082194)
  * 0001-ovsdb-Use-items-instead-of-iteritems-for-Python3.patch
  * 0002-ovsdb-ovsdb-dot.in-Use-print-function-for-Python3.patch
  * 0003-ovsdb-ovsdb-dot.in-Change-exception-semantics-for-Py.patch
  * 0004-ovsdb-ovsdb-dot.in-Replace-sys.maxint-with-sys.maxsi.patch
* Wed Feb 21 2018 mchandras@suse.de
- Version bump to 2.8.2 (bsc#1081953). Some of the changes are
  * ofp-meter: Fix use-after-free for decoding meter mods.
  * xlate: fix xport lookup for recirc
  * ofproto-dpif-xlate: add uuid to xports
  * netdev-dpdk: Fix requested MTU size validation.
  * netdev-dpdk: fix ingress_policer leak on error path
  * ofproto: Fix double-unref of temporary rule when learning.
  * gre: strip gre-tso offload flags
  * tc flower: reorder tunnel encap/decap actions
  * ofproto: Fix wrong datapath flow with same in_port and output port.
  * dpif: geneve: supply dpif function to get ifindex
  * ovs-tcpundump: fix a conversion issue
  * tunnel: fix tunnel flags set/clear.
  * netdev-dpdk: replace uint8_t with dpdk_port_t
  * lex: Fix parsing of long tokens.
  * odp-util: Use flexible sized buffer to hold Geneve options.
  * odp-util: Avoid reading wrong table in generate_all_wildcard_mask().
  * bond: Fix bug that writes to freed memory
  * conntrack: Fix icmp error address sanity check.
  * ovsdb-idl: Fix assertion failure on error path parsing server reply.
  * ofproto: Keep inserting buckets into a group from changing group type.
  * odp-util: Fix another hang in NSH action parsing.
  * odp-util: Fix parsing corner case for encap_nsh() actions.
  * netdev: netdev_get_etheraddr is not functioning as advertised.
  * ofproto-dpif-xlate: Fix bug that may leak ofproto_flow_mod
  * bfd: Fix memory leak
  * dpif: Fix memory leak
  * execution: Fix bug that leaks ovsdb_row
  * flow: Avoid buffer overread in parse_nsh() for malformed packet.
  * ovs-ofctl: Fix bad free in colors_parse_from_env().
  * odp-util: Fix buffer overread in parsing string form of ODP flows.
  * OpenvSwitch logrotate: Use ctl file path as target in ovs-appctl to reset logs
  * ovn-ctl: Add -vfile:info option to OVN_NB/SB_LOG options
  * netdev-tc-offloads: update stats properly on flow deletion
  * tests: Try harder to figure out whether IPv6 is supported.
  * netdev, dpif: fix the crash/assert on port delete
  * ovs-ctl: Don't remember vport-* kernel modules
  * NSH: Adjust NSH wire format to the latest IETF draft
  * ovs-lib: dont't purge corrupted DB
  * meta-flow: Fix format in documentation.
  * dpif-netlink-rtnl: Fix ovs_geneve probing after restart.
  * ovsdb-server: Fix memory leak
  * test-ovsdb: Fix memory leak
  * ovsdb-idl: Fix memory leak
  * netdev-linux: Fix wrong ceil rate when max-rate less than 8bit.
  * ofproto/trace: Fix memory leak in oftrace_push_ct_state()
  * ofproto-dpif-upcall: Fix null pointer dereference on exit.
  * ofproto-dpif-xlate: use xlate error enum for unsupported packet type
  * timeval: Check for OS-provided clock_gettime on macOS
  * Add dl_type to flow metadata for correct interpretation of conntrack metadata
  * Check flow's dl_type before setting ct_orig_tuple in 'pkt_metadata_from_flow()'
  * tests/stp: Use long warps instead of multiple calls.
  * ovs-save: Handle different 'ip addr show' output.
  * datapath-windows: Remove the workaround in NAT for TCP checksum
  * netdev: Fix memory leak on error path.
  * replication: Avoid theoretical use-after-free error in reset_database().
  * ovs-ctl.in: Call 'hostname -f' after vswitchd starts.
  * dpif-netdev: Use portable error code for zero rate meter band
- Remove patches that have been applied upstream:
  * 0001-netdev-dpdk-replace-uint8_t-with-dpdk_port_t.patch
* Tue Jan  9 2018 mchandras@suse.de
- Add upstream patches to support DPDK 17.11 (fate#322609)
  * 0001-netdev-dpdk-replace-uint8_t-with-dpdk_port_t.patch
  * 0002-netdev-dpdk-DPDK-v17.11-upgrade.patch
  * 0003-netdev-dpdk-vHost-IOMMU-support.patch
* Wed Dec 27 2017 mchandras@suse.de
- Python fixes and improvements
  * Build Python3 subpackages for Open vSwitch python bindings
  * Switch build architecture to 'noarch' for python bindings.
  * Fix license for python subpackages
  * Build and ship python bytecode files.
- Do not mark files in /usr/share/* as configuration files
- Replace version macro with actual version number of Obsoletes tags.
  The DPDK packages have been merged with the regular OvS ones in the
  2.7.0 release so make it more explicit which ones we are obsoleting.
- spec-cleaner fixes
* Wed Dec  6 2017 mchandras@suse.de
- Fix documentation installation. It's best to install everything to
  %%buildroot and then remove the files we don't need instead of the
  other way around since some files need to be present in the source
  directory for the testsuite to run.
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Sep 29 2017 mchandras@suse.de
- Version bump to 2.8.1. Some of the changes are:
  * connmgr: Fix violation of flow monitoring protocol description.
  * ovn/actions: Improve OVN load-balancing performance.
  * dpif-netdev: Fix a zero-rate bug for meter
  * conntrack: Tighten handling of alg reverse conns.
  * conntrack: Add function ct_print_conn_info().
  * conntrack: Create nat_conn_keys_insert().
  * netdev-dpdk: reset packet_type for reused dp_packets.
  * ofp-util: Fix memory leaks when parsing OF1.5 group properties (cve-2017-14970) (bsc#1061310)
  * ofp-util: Fix memory leaks on error cases in ofputil_decode_group_mod() (cve-2017-14970) (bsc#1061310)
  * ofp-util: Fix buffer overread in ofputil_decode_bundle_add().
  * ofproto: Include patch ports in mtu overriden check
  * netdev-tc-offloads: Fix vxlan tunnel offloading
  * bridge: Fix controller status update to passive connections
  * lib/odp: Fix handling of set masked action in parse_odp_action
  * tests: Fix sparse error on test-ovn.c
  * dpif-netdev: Fix per packet cycles statistics.
  * netdev-dpdk: update vhost user client port status.
  * ovsdb-server.1: Fix mention of wrong option.
* Mon Sep  4 2017 mchandras@suse.de
- Version bump to 2.8.0 (fate#323334, bsc#1050700). Some of the changes are:
  * ovs-ofctl can now accept and display port names in place of numbers.  By
    default it always accepts names and in interactive use it displays them;
    use --names or --no-names to override.  See ovs-ofctl(8) for details.
  * "ovs-ofctl dump-flows" now accepts --no-stats to omit flow statistics.
  * New ovs-dpctl command "ct-stats-show" to show connection tracking stats.
  * DPDK log messages redirected to OVS logging subsystem.
    Log level can be changed in a usual OVS way using
    'ovs-appctl vlog' commands for 'dpdk' module. Lower bound
    still can be configured via extra arguments for DPDK EAL.
  * dpdkvhostuser ports are marked as deprecated.  They will be removed
    in an upcoming release.
  * Support for DPDK v17.05.1.
  * New support for multiple VLANs (802.1ad or "QinQ"), including a new
    "dot1q-tunnel" port VLAN mode.
  * Added NAT support for userspace datapath.
  * Added FTP and TFTP support with NAT for userspace datapath.
  * Experimental NSH (Network Service Header) support in userspace datapath.
  * Tracing with ofproto/trace now traces through recirculation.
  * New support for role-based access control (see ovsdb-server(1)).
  * New commands 'stp/show' and 'rstp/show' (see ovs-vswitchd(8)).
  * All features required by OpenFlow 1.4 are now implemented, so
    ovs-vswitchd now enables OpenFlow 1.4 by default (in addition to
    OpenFlow 1.0 to 1.3).
  * Increased support for OpenFlow 1.6 (draft).
  * Bundles now support hashing by just nw_src or nw_dst.
  * The "learn" action now supports a "limit" option (see ovs-ofctl(8)).
  * The port status bit OFPPS_LIVE now reflects link aliveness.
  * OpenFlow 1.5 packet-out is now supported.
  * Support for OpenFlow 1.5 field packet_type and packet-type-aware
    pipeline (PTAP).
  * Added generic encap and decap actions (EXT-382).
    First supported use case is encap/decap for Ethernet.
  * Added NSH (Network Service Header) support in userspace
    Used generic encap and decap actions to implement encapsulation and
    decapsulation of NSH header.
    IETF NSH draft - https://datatracker.ietf.org/doc/draft-ietf-sfc-nsh/
  * ovs-vswitchd and ovsdb-server run as non-root users by default.
  * Add --cleanup option to command 'ovs-appctl exit' (see ovs-vswitchd(8)).
  * Use new tunnel port option "packet_type" to configure L2 vs. L3.
  * In conjunction with PTAP tunnel ports can handle a mix of L2 and L3
    payload.
  * New vxlan tunnel extension "gpe" to support VXLAN-GPE tunnels.
  * New support for non-Ethernet (L3) payloads in GRE and VXLAN-GPE.
  * Add experimental support for hardware offloading
  * HW offloading is disabled by default.
  * HW offloading is done through the TC interface.
  * The next major version of OVS will introduce a change in the
    conntrack API.  Conntrack state is only available to the processing
    path that follows the "recirc_table" argument of the ct() action.
    Starting in OVS 2.9, this state will be cleared for the current
    processing path whenever ct() is called.
- Create new openvswitch-doc subpackage for the Open vSwitch documentation
- Fix filename for logrotate configuration (bsc#1057357)
- Fix constrains with Provides/Obsoletes tags (bsc#1057357)
- Misc cleanups from spec-cleaner
* Thu Aug 10 2017 olaf@aepfle.de
- Update filename in /var/adm/update-messages to match documentation,
  and build-compare pattern
* Thu Jul 27 2017 mchandras@suse.de
- Do not restart the ovs-vswitchd and ovsdb-server services
  on package updates (bsc#1002734)
- Do not restart the ovs-vswitchd, ovsdb-server and openvswitch
  services on package removals. This facilitates potential future
  package moves but also preserves connectivity when the package is
  removed (bsc#1050896)
* Wed Jul 19 2017 mchandras@suse.de
- Version bump to 2.7.2. Some of the changes are:
  * Revert "netdev: Fix netdev_open() to adhere to class type if given"
  * connmgr: Fix crash when in_band_create() fails.
  * db-ctl-base: Fix reference-following feature in get_row_by_id().
  * netdev: Fix crash when ifa_netmask is null.
  * ovn-controller: fix use-after-free in physical_run()
  * ovn-controller: avoid crash when vswitchd connection is lost
  * ovsdb-types: Fix memory leak on error path.
  * vswitchd: Fix IFACE_STAT name error in iface_refresh_stats
  * netdev: Fix crash when interface option is changed to invalid value.
  * ofp-util: fix memory leak in ofputil_pull_ofp11_buckets
  * configure: Fix check for rte_config.h to handle cross-compilation.
  * ofp-util: Check length of buckets in ofputil_pull_ofp15_group_mod() (cve-2017-9265) (bsc#1041447)
  * ofp-print: Don't abort on unknown reason in role status message (cve-2017-9263) (bsc#1041470)
* Sat Jul  8 2017 jengelh@inai.de
- Remove irrelevant wording from summaries/description.
  Diversify summaries.
- Get rid of an empty if block by inverting the condition.
- Implement shared library packaging guideline.
* Thu Jul  6 2017 mchandras@suse.de
- Version bump to 2.7.1. Some of the changes are:
  * Add --cleanup option to command 'ovs-appctl exit' (see ovs-vswitchd(8)).
  * libopenvswitch-2 was renamed to libopenvswitch-2.7. Applications built
    against libopenvswitch must be recompiled against the newer library.
  * ovs-ctl: allow passing user:group to daemons
  * ofproto/bond: Fix bond reconfiguration race condition
  * ofproto/bond: Fix bond post recirc rule leak.
  * ofproto/bond: fix interal flow leak of tcp-balance bond
  * mcast-snooping: Avoid segfault for vswitchd.
  * tun-metadata: Fix memory leak in tun_metadata_table_mod().
  * netdev-dpdk: Fix mempool segfault.
  * mirror: Allow concurrent lookups.
  * ofp-util: Fix buffer overread in ofputil_pull_queue_get_config_reply10() (bsc#1040543)
  * ovsdb: Check null before deref in ovsdb_monitor_table_condition_update().
  * For the complete list of changes, please see:
  - https://github.com/openvswitch/ovs/compare/v2.7.0...v2.7.1
- Remove upstreamed patch
  * 0001-ofp-util-Fix-buffer-overread-in-ofputil_pull_queue_g.patch
- OVN services are no longer restarted automatically after upgrade (44dd4cc49c8a)
* Sat May 27 2017 mchandras@suse.de
- Install firewalld OVN files with chmod 644 instead of 755 (4a54614120ea)
- Use python-six instead of python2-six dependency to cover distributions
  which are not using the python-singlespec packaging specification yet (bsc#1041110)
- Add upstream patch to fix a buffer overread vulnerability (cve-2017-9214) (bsc#1040543)
  * 0001-ofp-util-Fix-buffer-overread-in-ofputil_pull_queue_g.patch
* Tue Feb 28 2017 mchandras@suse.de
- Version bump to 2.7.0 (fate#321541). Some of the changes are:
  * Utilities and daemons that support SSL now allow protocols and
    ciphers to be configured with --ssl-protocols and --ssl-ciphers.
  * OVN:
  - QoS is now implemented via egress shaping rather than ingress policing.
  - DSCP marking is now supported, via the new northbound QoS table.
  - IPAM now supports fixed MAC addresses.
  - Support for source IP address based routing.
  - ovn-trace:
  * New --ovs option to also print OpenFlow flows.
  * put_dhcp_opts and put_dhcp_optsv6 actions may now be traced.
  - Support for managing SSL and remote connection configuration in
    northbound and southbound databases.
  * Fixed regression in table stats maintenance introduced in OVS
    2.3.0, wherein the number of OpenFlow table hits and misses was
    not accurate.
  * OpenFlow:
  - OFPT_PACKET_OUT messages are now supported in bundles.
  - A new "selection_method=dp_hash" type for OpenFlow select group
    bucket selection that uses the datapath computed 5-tuple hash
    without making datapath flows match the 5-tuple fields, which
    is useful for more efficient load balancing, for example.  This
    uses the Netronome extension to OpenFlow 1.5+ that allows
    control over the OpenFlow select groups selection method.  See
    "selection_method" and related options in ovs-ofctl(8) for
    details.
  - The "sample" action now supports "ingress" and "egress" options.
  - The "ct" action now supports the TFTP ALG where support is available.
  - New actions "clone" and "ct_clear".
  * ovs-ofctl:
  - 'bundle' command now supports packet-out messages.
  - New syntax for 'ovs-ofctl packet-out' command, which uses the
    same string parser as the 'bundle' command.  The old 'packet-out'
    syntax is deprecated and will be removed in a later OVS
    release.
  - New unixctl "ofctl/packet-out" command, which can be used to
    instruct a flow monitor to issue OpenFlow packet-out messages.
  * ovsdb-server:
  - Remote connections can now be made read-only (see ovsdb-server(1)).
  * DPDK:
  - Support for DPDK v16.11.
  - Support for rx checksum offload. Refer DPDK HOWTO for details.
  - Port Hotplug is now supported.
  - DPDK physical ports can now have arbitrary names. The PCI address of
    the device must be set using the 'dpdk-devargs' option. Compatibility
    with the old dpdk<portid> naming scheme is broken, and as such a
    device will not be available for use until a valid dpdk-devargs is
    specified.
  - Virtual DPDK Poll Mode Driver (vdev PMD) support.
  * For the complete list of changes, please see:
  - http://openvswitch.org/releases/NEWS-2.7.0
- Add patch to fix DPDK configuration migration for < 2.6 installations
  * 0001-utilities-Add-script-to-support-DPDK-option-migratio.patch
- Rework spec file
  * Enable DPDK by default and drop openvswitch-dpdk* packages. DPDK is only
    enabled on supported architectures though.
  - Remove openvswitch-dpdk.changes
  - Remove openvswitch-dpdk.spec
  - Remove pre_checkin.sh
  * Merge openvswitch and openvswitch-switch into a single package since there
    was no compelling reason to keep the switch functionality in a separate
    subpackage.
  * Split OVN package to ovn-common, ovn-central, ovn-docker, ovn-host and
    ovn-controller similar to the Debian and RedHat packages.
* Fri Nov 25 2016 mchandras@suse.de
- Relax the DPDK dependency a bit so we can support stable and
  possibly new minor releases as well.
* Mon Nov 21 2016 mchandras@suse.de
- Do not restart the openvswitch service after a package update.
  Restarting the systemd service may break connectivity so let the
  user decide when it is the best time for such an action. (bsc#1002734)
* Thu Nov  3 2016 mchandras@suse.de
- Version bump to 2.6.1. Some of the changes are:
  * ovn: Do not reply to ARP or ND NS for a VM's own IP address.
  * ovs-ofctl: Tolerate differences in IPv6 formatting.
  * netdev-linux: double tagged packets should use 0x88a8
  * expr: Fix abort when simplifying "x != 0/0".
  * dpif-netdev: Fix crash in dpif_netdev_execute().
  * ovn-controller: Container can have connection to a hosting VM.
  * stream-ssl: Fix memory leak on error path.
  * Other bug fixes.
* Mon Oct  3 2016 mchandras@suse.de
- Version bump to 2.6.0. Some of the changes are:
  * First supported release of OVN.  See ovn-architecture(7) for more
    details.
  * ovsdb-server:
  - New "monitor_cond" "monitor_cond_update" and "update2" extensions to
    RFC 7047.
  * OpenFlow:
  - OpenFlow 1.3+ bundles now expire after 10 seconds since the
    last time the bundle was either opened, modified, or closed.
  - OpenFlow 1.3 Extension 230, adding OpenFlow Bundles support, is
    now implemented.
  - OpenFlow 1.3+ bundles are now supported for group mods as well as
    flow mods and port mods.  Both 'atomic' and 'ordered' bundle
    flags are supported for group mods as well as flow mods.
  - Internal OpenFlow rule representation for load and set-field
    actions is now much more memory efficient.  For a complex flow
    table this can reduce rule memory consumption by 40%%.
  - Bundles are now much more memory efficient than in OVS 2.5.
    Together with memory efficiency improvements in OpenFlow rule
    representation, the peak OVS resident memory use during a
    bundle commit for large complex set of flow mods can be only
    25%% of that in OVS 2.5 (4x lower).
  - OpenFlow 1.1+ OFPT_QUEUE_GET_CONFIG_REQUEST now supports OFPP_ANY.
  - OpenFlow 1.4+ OFPMP_QUEUE_DESC is now supported.
  - OpenFlow 1.4+ OFPT_TABLE_STATUS is now supported.
  - New property-based packet-in message format NXT_PACKET_IN2 with support
    for arbitrary user-provided data and for serializing flow table
    traversal into a continuation for later resumption.
  - New extension message NXT_SET_ASYNC_CONFIG2 to allow OpenFlow 1.4-like
    control over asynchronous messages in earlier versions of OpenFlow.
  - [...]
  - For a complete list of changes, please see
    http://openvswitch.org/releases/NEWS-2.6.0
- Remove obsolete patches and files
  * 0001-Remove-broken-pipe-warning-logs-from-ovsdb-server.lo.patch
  * 0001-ovs-ctl-Add-new-DPDK_OPTIONS-environment-variable.patch
  * openvswitch-2.5.0-detect-dpdk-installation.patch
  * openvswitch-switch.logrotate
  * openvswitch.service
* Wed Sep 28 2016 mchandras@suse.de
- New upstream bugfix release 2.5.1 (bsc#1001657)
  * DPDK:
  - New appctl command 'dpif-netdev/pmd-rxq-show' to check the port/rxq
    assignment.
  - Type of log messages from PMD threads changed from INFO to DBG.
  * ovs-pki: Changed message digest algorithm from SHA-1 to SHA-512 because
    SHA-1 is no longer secure and some operating systems have started to
    disable it in OpenSSL.
  * Bug fixes
* Tue Sep  6 2016 mchandras@suse.de
- Add new DPDK_OPTIONS environment variable to hold the dpdk
  vswitchd options so that the systemd unit files can be used to
  launch an ovs-vswitcd DPDK capable instance instead of doing
  it manually. (bsc#987265)
  * 0001-ovs-ctl-Add-new-DPDK_OPTIONS-environment-variable.patch
* Sun Aug 14 2016 ro@suse.de
- enable openvswitch-dpdk on aarch64 since dpdk
  builds on aarch64 now
* Sun Aug  7 2016 ro@suse.de
- remove aarch from openvswitch-dpdk until we have a dpdk
  that builds for aarch64
* Tue Jul 12 2016 mchandras@suse.de
- Add missing licenses (bsc#988513)
- Misc spec file cleanups highlighted by the spec-cleaner tool.
- Allow aarch64 builds for openvswitch-dpdk
* Mon Jul  4 2016 mchandras@suse.de
- Allow the OvS daemon to run as non-root (bsc#987545)
- Add missing 'Conflicts' statements to all the subpackages as
  required by the Factory review tools.
* Wed Jun 29 2016 mchandras@suse.de
- Remove the ?_with_dpdk macro usage since this is not being set
  without explicitly passing --with/--without during an OBS build.
  This reverts back to using the %%{with dpdk} style which is set
  automatically based on %%bcond_with* macros (bsc#989335).
* Tue Jun 28 2016 mchandras@suse.de
- Fix subpackage dependencies to not require the non-existent python
  DPDK subpackages (bsc#986835). We do not provide DPDK versions of
  the python bindings so nothing should depend on these subpackages.
* Wed Jun 22 2016 jengelh@inai.de
- Update rpm groups, acronym forms.
* Tue Jun 21 2016 mchandras@suse.de
- Multiple fixes for the openvswitch-dpdk package (bsc#985878)
  * Rename main package name to openvswitch-dpdk
  * Do not build the python and kmp packages since they do not
    depend on the DPDK capabilities
  * Remove the open_virtual_switch capability. The
    openvswitch-common will be used by reverse dependencies to
    require either of the OvS packages.
  * Provide virtual capabilities for all DPDK subpackages.
  * Fix the dependencies in the python package to require either
    of the OvS packages.
  * Suggest the kmp package only if it's actually provided.
  * Small cleanups.
* Fri May 27 2016 mchandras@suse.de
- Add %%check directive to run the openvswitch testsuite on demand.
  The openvswitch contains hundreds of tests covering simple and
  complex openvswitch configuration so it's beneficial to run them
  during package builds. However, running the testsuite is not enabled
  by default. Also add the following upstream patch:
  * 0001-Remove-broken-pipe-warning-logs-from-ovsdb-server.lo.patch
* Thu May 26 2016 mchandras@suse.de
- Build a DPDK-enabled Open vSwitch (fate#319170)
  * Apply the following changes to the openvswitch.spec file
  - Add support for building with DPDK capabilities
  - Add conflicts between the two packages.
  - Add new 'open_virtual_switch-*' capabilities for openvswitch,
    openvswitch-switch, openvswitch-test packages which can be used
    by reverse dependencies to select between the two openvswitch
    implementations.
  * Add pre_checkin.sh to generate the openvswitch_dpdk.spec file
    based on the openvswitch.spec one.
  * Add upstream openvswitch-2.5.0-detect-dpdk-installation.patch
    patch to detect and link against a DPDK installation.
* Mon May 23 2016 jengelh@inai.de
- Keep %%prep small for speedier `quilt setup`. Kill __DATE__ from
  source. Drop all .la files that are in %%_libdir.
* Fri May 20 2016 mchandras@suse.de
- Add missing %%dir directive for /var/log/openvswitch
* Thu May 19 2016 dmueller@suse.com
- remove aarch64 conditional, no longer needed
* Thu May  5 2016 mchandras@suse.de
- Multiple spec file and package fixes.
  * Drop obsolete log-check-module-loop.patch patch.
  * Drop conditional code for older openSUSE releases. This also removes
    all of the sysvinit files which were pulled in when the package was
    originally developed.
  * Drop support for building the GUI. The GUI code has been removed in
    7868fbc6c97c2 ("ovsdbmonitor: Remove.") upstream commit and it does
    not exist since v2.2.0 so drop the code in the spec file.
  * Use the upstream systemd service files for the OVN components instead
    of maintaining our own downstream.
  * Drop the unofficial ipsec support. It hasn't been enabled in years.
  * Drop support for building the upstream kernel module since it's being
    shipped with the kernel package in latest releases. Restore the
    %%bcond_with kmp to make it easier to build the external kernel module
    if needed.
  * Fix some suse-missing-rclink rpmlint warnings for the ovn subpackage
  * Base our service unit to the upstream one.
  * Stop silently enabling the GRE protocol in iptables by default.
  * Install the upstream sysconfig file to pass more information to the
    openvswitch service unit.
  * Use make install instead of %%makeinstall
  * Drop brcompat leftovers.
  * spec-cleaner fixes
* Fri Apr  1 2016 dmueller@suse.com
- address dimstars concerns
* Tue Mar 22 2016 mchandras@suse.de
- Prevent systemd from autogenerating a service file for
  openvswitch-switch which conflicts with the opevswitch
  one. (bsc#966762)
* Fri Mar 18 2016 kmroz@suse.com
- Add missing %%defattr to ovn files section.
* Tue Mar  8 2016 kmroz@suse.com
- Add additional install requirements for python-openvswitch-test
  package.
* Fri Mar  4 2016 kmroz@suse.com
- Add support for building both 2.4.0 and 2.5.0 from the same spec
  file. Needed to fix SLE11 builds as OVS-2.5.0 no longer supports
  python < 2.7. SLE11 SP3 and SP4 use python 2.6.
- Added: openvswitch-2.4.0.tar.gz
* Thu Mar  3 2016 kmroz@suse.com
- New upstream version 2.5.0 (LTS)
  - Dropped support for Python older than version 2.7.  As a consequence,
    using Open vSwitch 2.5 or later on XenServer 6.5 or earlier (which
    have Python 2.4) requires first installing Python 2.7.
  - OpenFlow:
  * Group chaining (where one OpenFlow group triggers another) is
    now supported.
  * OpenFlow 1.4+ "importance" is now considered for flow eviction.
  * OpenFlow 1.4+ OFPTC_EVICTION is now implemented.
  * OpenFlow 1.4+ OFPTC_VACANCY_EVENTS is now implemented.
  * OpenFlow 1.4+ OFPMP_TABLE_DESC is now implemented.
  * Allow modifying the ICMPv4/ICMPv6 type and code fields.
  * OpenFlow 1.4+ OFPT_SET_ASYNC_CONFIG and OFPT_GET_ASYNC_CONFIG are
    now implemented.
  - ovs-ofctl:
  * New "out_group" keyword for OpenFlow 1.1+ matching on output group.
  - Tunnels:
  * Geneve tunnels can now match and set options and the OAM bit.
  * The nonstandard GRE64 tunnel extension has been dropped.
  - Support Multicast Listener Discovery (MLDv1 and MLDv2).
  - Add 'symmetric_l3l4' and 'symmetric_l3l4+udp' hash functions.
  - sFlow agent now reports tunnel and MPLS structures.
  - New 'check-system-userspace', 'check-kmod' and 'check-kernel' Makefile
    targets to run a new system testsuite.  These tests can be run inside
    a Vagrant box.  See INSTALL.md for details
  - Mark --syslog-target argument as deprecated.  It will be removed in
    the next OVS release.
  - Added --user option to all daemons
  - Add support for connection tracking through the new "ct" action
    and "ct_state"/"ct_zone"/"ct_mark"/"ct_label" match fields.  Only
    available on Linux kernels with the connection tracking module loaded.
  - Add experimental version of OVN.  OVN, the Open Virtual Network, is a
    system to support virtual network abstraction.  OVN complements the
    existing capabilities of OVS to add native support for virtual network
    abstractions, such as virtual L2 and L3 overlays and security groups.
  - RHEL packaging:
  * DPDK ports may now be created via network scripts (see README.RHEL).
  - DPDK:
  * Requires DPDK 2.2
  * Added multiqueue support to vhost-user
  * Note: QEMU 2.5+ required for multiqueue support
  - SELinux:
  * Introduced SELinux policy package.
- New package: openvswitch-ovn
- Removed: openvswitch-2.4.0.tar.gg
- Added: openvswitch-2.5.0.tar.gg
- Added: openvswitch-testcontroller.init
- Added: ovn-controller-vtep.service
- Added: ovn-controller.service
- Added: ovn-northd.service
- TODO: Explicit DPDK support not yet added to spec.
- Spec file work and cleanup.
- Includes fixes (or obsoletes) the following issues:
  * bsc#948840, bsc#941466, bsc#936780, bnc#935750, bnc#867964
* Tue Mar  1 2016 kmroz@suse.com
- Tighten up openvswitch service ordering.
  bsc#968205 (openSUSE), bsc#951314 (SLE).
* Wed Feb 24 2016 kmroz@suse.com
- Don't install INSTALL.* files.
* Wed Feb 24 2016 kmroz@suse.com
- Removed: openvswitch-switch.template
* Wed Feb 24 2016 kmroz@suse.com
- New upstream version 2.4.0
  - Flow table modifications are now atomic, meaning that each packet
    now sees a coherent version of the OpenFlow pipeline.  For
    example, if a controller removes all flows with a single OpenFlow
    "flow_mod", no packet sees an intermediate version of the OpenFlow
    pipeline where only some of the flows have been deleted.
  - Added support for SFQ, FQ_CoDel and CoDel qdiscs.
  - Add bash command-line completion support for ovs-vsctl Please check
    utilities/ovs-command-compgen.INSTALL.md for how to use.
  - The MAC learning feature now includes per-port fairness to mitigate
    MAC flooding attacks.
  - New support for a "conjunctive match" OpenFlow extension, which
    allows constructing OpenFlow matches of the form "field1 in
    {a,b,c...} AND field2 in {d,e,f...}" and generalizations.  For details,
    see documentation for the "conjunction" action in ovs-ofctl(8).
  - Add bash command-line completion support for ovs-appctl/ovs-dpctl/
    ovs-ofctl/ovsdb-tool commands.  Please check
    utilities/ovs-command-compgen.INSTALL.md for how to use.
  - The "learn" action supports a new flag "delete_learned" that causes
    the learned flows to be deleted when the flow with the "learn" action
    is deleted.
  - Basic support for the Geneve tunneling protocol. It is not yet
    possible to generate or match options. This is planned for a future
    release. The protocol is documented at
    http://tools.ietf.org/html/draft-gross-geneve-00
  - The OVS database now reports controller rate limiting statistics.
  - sflow now exports information about LACP-based bonds, port names, and
    OpenFlow port numbers, as well as datapath performance counters.
  - ovs-dpctl functionality is now available for datapaths integrated
    into ovs-vswitchd, via ovs-appctl.  Some existing ovs-appctl
    commands are now redundant and will be removed in a future
    release.  See ovs-vswitchd(8) for details.
  - OpenFlow:
  * OpenFlow 1.4 bundles are now supported for flow mods and port
    mods.  For flow mods, both 'atomic' and 'ordered' bundle flags
    are trivially supported, as all bundled messages are executed
    in the order they were added and all flow table modifications
    are now atomic to the datapath.  Port mods may not appear in
    atomic bundles, as port status modifications are not atomic.
  * IPv6 flow label and neighbor discovery fields are now modifiable.
  * OpenFlow 1.5 extended registers are now supported.
  * The OpenFlow 1.5 actset_output field is now supported.
  * OpenFlow 1.5 Copy-Field action is now supported.
  * OpenFlow 1.5 masked Set-Field action is now supported.
  * OpenFlow 1.3+ table features requests are now supported (read-only).
  * Nicira extension "move" actions may now be included in action sets.
  * "resubmit" actions may now be included in action sets.  The resubmit
    is executed last, and only if the action set has no "output" or "group"
    action.
  * OpenFlow 1.4+ flow "importance" is now maintained in the flow table.
  * A new Netronome extension to OpenFlow 1.5+ allows control over the
    fields hashed for OpenFlow select groups.  See "selection_method" and
    related options in ovs-ofctl(8) for details.
  - ovs-ofctl has a new '--bundle' option that makes the flow mod commands
    ('add-flow', 'add-flows', 'mod-flows', 'del-flows', and 'replace-flows')
    use an OpenFlow 1.4 bundle to operate the modifications as a single
    atomic transaction.  If any of the flow mods in a transaction fail, none
    of them are executed.  All flow mods in a bundle appear to datapath
    lookups simultaneously.
  - ovs-ofctl 'add-flow' and 'add-flows' commands now accept arbitrary flow
    mods as an input by allowing the flow specification to start with an
    explicit 'add', 'modify', 'modify_strict', 'delete', or 'delete_strict'
    keyword.  A missing keyword is treated as 'add', so this is fully
    backwards compatible.  With the new '--bundle' option all the flow mods
    are executed as a single atomic transaction using an OpenFlow 1.4 bundle.
  - ovs-pki: Changed message digest algorithm from MD5 to SHA-1 because
    MD5 is no longer secure and some operating systems have started to disable
    it in OpenSSL.
  - ovsdb-server: New OVSDB protocol extension allows inequality tests on
    "optional scalar" columns.  See ovsdb-server(1) for details.
  - ovs-vsctl now permits immutable columns in a new row to be modified in
    the same transaction that creates the row.
  - test-controller has been renamed ovs-testcontroller at request of users
    who find it useful for testing basic OpenFlow setups.  It is still not
    a necessary or desirable part of most Open vSwitch deployments.
  - Support for travis-ci.org based continuous integration builds has been
    added. Build failures are reported to build@openvswitch.org. See INSTALL.md
    file for additional details.
  - Support for the Rapid Spanning Tree Protocol (IEEE 802.1D-2004).
    The implementation has been tested successfully against the Ixia Automated
    Network Validation Library (ANVL).
  - Stats are no longer updated on fake bond interface.
  - Keep active bond slave selection across OVS restart.
  - A simple wrapper script, 'ovs-docker', to integrate OVS with Docker
    containers. If and when there is a native integration of Open vSwitch
    with Docker, the wrapper script will be retired.
  - Added support for DPDK Tunneling. VXLAN, GRE, and Geneve are supported
    protocols. This is generic tunneling mechanism for userspace datapath.
  - Support for multicast snooping (IGMPv1, IGMPv2 and IGMPv3)
  - Support for Linux kernels up to 4.0.x
  - The documentation now use the term 'destination' to mean one of syslog,
    console or file for vlog logging instead of the previously used term
    'facility'.
  - Support for VXLAN Group Policy extension
  - Initial support for the IETF Auto-Attach SPBM draft standard. This
    contains rudimentary support for the LLDP protocol as needed for
    Auto-Attach.
  - The default OpenFlow and OVSDB ports are now the IANA-assigned
    numbers.  OpenFlow is 6653 and OVSDB is 6640.
  - Support for DPDK vHost.
  - Support for outer UDP checksums in Geneve and VXLAN.
  - The kernel vports with dependencies are no longer part of the overall
    openvswitch.ko but built and loaded automatically as individual kernel
    modules (vport-*.ko).
  - Support for STT tunneling.
  - Support to configure method (--syslog-method argument) that determines
    how daemons will talk with syslog.
  - Support for "ovs-appctl vlog/list-pattern" command that lets to query
    logging message format for each destination.
  - GRE64 and ipsec_gre64 tunnel protocol is deprecated and will be removed
    from OVS v2.5 release.
  * The openvswitch-testcontroller package is new.  It reintroduces the
    simple OpenFlow controller that was packaged with Open vSwitch prior to
    version 2.1, at request of users who find it useful for testing basic
    OpenFlow setups.  It is still not a necessary or desirable part of most
    Open vSwitch deployments.
- Fixed: log-check-module-loop.patch to work with new version.
- Removed: openvswitch-2.3.1.tar.gz
- Added: openvswitch-2.4.0.tar.gz
- Spec file work and cleanup.
* Sun Jan 10 2016 antoine.belvire@laposte.net
- Add calls to /sbin/ldconfig in %%post and %%postun
- Fix typo in Url
* Sun Dec 28 2014 andrea@opensuse.org
- new upstream version 2.3.1
  - Compatibility with autoconf 2.63 (previously >=2.64)
  - ovs-pki: Changed message digest algorithm from MD5 to SHA-1 because
    MD5 is no longer secure and some operating systems have started to disable
    it in OpenSSL.
  - Keep active bond slave selection across OVS restart.
  * v2.3.0 - 14 Aug 2014
  - OpenFlow 1.1, 1.2, and 1.3 are now enabled by default in
    ovs-vswitchd.
  - Linux kernel datapath now has an exact match cache optimizing the
    flow matching process.
  - Datapath flows now have partially wildcarded tranport port field
    matches.  This reduces userspace upcalls, but increases the
    number of different masks in the datapath.  The kernel datapath
    exact match cache removes the overhead of matching the incoming
    packets with the larger number of masks, but when paired with an
    older kernel module, some workloads may perform worse with the
    new userspace.
  * v2.2.0 - Internal Release
  - Internal ports are no longer brought up by default, because it
    should be an administrator task to bring up devices as they are
    configured properly.
  - ovs-vsctl now reports when ovs-vswitchd fails to create a new port or
    bridge.
  - The "ovsdbmonitor" graphical tool has been removed, because it was
    poorly maintained and not widely used.
  - New "check-ryu" Makefile target for running Ryu tests for OpenFlow
    controllers against Open vSwitch.  See INSTALL for details.
  - Added IPFIX support for SCTP flows and templates for ICMPv4/v6 flows.
  - Upon the receipt of a SIGHUP signal, ovs-vswitchd no longer reopens its
    log file (it will terminate instead). Please use 'ovs-appctl vlog/reopen'
    instead.
  - Support for Linux kernels up to 3.14. From Kernel 3.12 onwards OVS uses
    tunnel API for GRE and VXLAN.
  - Added experimental DPDK support.
  - Added support for custom vlog patterns in Python
- removed datapath-Add-support-for-Linux-3.12.patch no more required
- removed sle11-device-ops-backport.diff , not used before
* Tue Oct 21 2014 dmueller@suse.com
- fix rcX link
* Tue Sep 23 2014 dmueller@suse.com
- disable shipped kmp module build for newer distros
* Mon Sep 22 2014 dmueller@suse.com
- update to 2.1.3:
  datapath: Drop packets when interdev is not up
  Fix two memory leaks.
  tests: Remove extraneous parenthesis from test name.
  build: Allow building with autoconf 2.63
  ovsdb: Don't add ovsdb-server.c to libovsdb.
  stp: Make stp-disabled port forward stp bpdu packets.
  dpif-linux: Fix bad backport in previous commit.
  dpif-linux: Avoid null dereference if all ports disappear.
  ofp-msgs: Correct code for queue configuration messages in OpenFlow 1.0.
  ofp-util: Fix null pointer dereference in ofputil_pull_buckets().
  tests: Disable glibc memory checking under glibc <= 2.11.
  datapath/flow_netlink: Fix NDP flow mask validation
  datapath: Change u64_stats_* to use _irq instead of _bh().
  datapath: Use exact lookup for flow_get and flow_del.
  json: Fix parsing of strings that end with a backslash.
  dpif: When executing actions needs help, use "set" action to set tunnel.
  datapath: Rehash 16-bit skbuff hashes into 32 bits.
  upcall: Configure datapath max-idle through ovs-vsctl.
  upcall: Add appctl call to set flow_limit.
  stream-ssl: Enable TLSv1.1 and TLSv1.2.
  lib/classifier: Fix use of uninitialized memory.
  lib/classifier: Clarify trie_lookup_value().
  ovs-lib: allow non-root users to check service status
  rhel: Add Patch Port support to initscripts
  rhel: support persistent mac addresses on OVS bridges
  netflow: Fold netflow_expire() into netflow_flow_clear().
  ofproto: Fix memory leak in ofproto_destroy().
  ofproto: Send monitor updates if a flow mod changes a rules actions
  lib/match: Add mask bits for nd_target for ICMPv6
  bridge: Initialize dscp for mgmt connections.
  datapath: Fix build from stats backport.
  openvswitch: fix a possible deadlock and lockdep warning
  AUTHORS: Fix spelling of Anoob Soman's name.
  ofproto-dpif-xlate: Fix null pointer dereference
  ovs-ctl: Don't decrease max open fds if already set higher
  Makefiles: Fix invocation of dot2pic when builddir != srcdir.
  dot2pic: Stop assuming the path of the interpreter
  dot2pic: Use "> $@; mv $@.tmp $@" notation to make this reliably fail
  tunnel: Fix bug where misconfiguration persists.
  netdev: Safely increment refcount in netdev_open().
  datapath: Fix feature check for HAVE_RXHASH.
  datapath: clear l4_rxhash in skb_clear_hash.
  ofproto-dpif-xlate: Fix in_port=controller case for NORMAL action
* Fri May  2 2014 e.istomin@edss.ee
- updated to 2.1.2.
  This contains bug fixes related to sending packet-in messages to the controller.
* Tue Apr 29 2014 e.istomin@edss.ee
- updated to 2.1.1. This release removes the "ovsdbmonitor" program and contains bug fixes.
* Wed Apr  2 2014 kmroz@suse.com
- Prevent ovsdb-server from entering an infinite loop when
  processing logging levels during bringup.
  added: log-check-module-loop.patch
* Thu Mar 27 2014 dmueller@suse.com
- update to 2.1.0:
  - Address prefix tracking support for flow tables.  New columns
    "prefixes" in OVS-DB table "Flow_Table" controls which packet
    header fields are used for address prefix tracking.  Prefix
    tracking allows the classifier to skip rules with longer than
    necessary prefixes, resulting in better wildcarding for datapath
    flows.  Default configuration is to not use any fields for prefix
    tracking.  However, if any flow tables contain both exact matches
    and masked matches for IP address fields, OVS performance may be
    increased by using this feature.
  * As of now, the fields for which prefix lookup can be enabled
    are: 'tun_id', 'tun_src', 'tun_dst', 'nw_src', 'nw_dst' (or
    aliases 'ip_src' and 'ip_dst'), 'ipv6_src', and 'ipv6_dst'.
    (Using this feature for 'tun_id' would only make sense if the
    tunnel IDs have prefix structure similar to IP addresses.)
  * There is a maximum number of fields that can be enabled for any
    one flow table.  Currently this limit is 3.
  * Examples:
    $ ovs-vsctl set Bridge br0 flow_tables:0=@N1 -- \
  - -id=@N1 create Flow_Table name=table0
    $ ovs-vsctl set Bridge br0 flow_tables:1=@N1 -- \
  - -id=@N1 create Flow_Table name=table1
    $ ovs-vsctl set Flow_Table table0 prefixes=ip_dst,ip_src
    $ ovs-vsctl set Flow_Table table1 prefixes=[]
  - TCP flags matching: OVS now supports matching of TCP flags.  This
    has an adverse performance impact when using OVS userspace 1.10
    or older (no megaflows support) together with the new OVS kernel
    module.  It is recommended that the kernel and userspace modules
    both are upgraded at the same time.
  - The default OpenFlow and OVSDB ports will change to
    IANA-assigned numbers in a future release.  Consider updating
    your installations to specify port numbers instead of using the
    defaults.
  - OpenFlow:
  * The OpenFlow 1.1+ "Write-Actions" instruction is now supported.
  * OVS limits the OpenFlow port numbers it assigns to port 32767 and
    below, leaving port numbers above that range free for assignment
    by the controller.
  * ovs-vswitchd now honors changes to the "ofport_request" column
    in the Interface table by changing the port's OpenFlow port
    number.
  - ovs-vswitchd.conf.db.5 man page will contain graphviz/dot
    diagram only if graphviz package was installed at the build time.
  - Support for Linux kernels up to 3.11
  - ovs-dpctl:
    The "show" command also displays mega flow mask stats.
  - ovs-ofctl:
  * New command "ofp-parse-pcap" to dump OpenFlow from PCAP files.
  - ovs-controller has been renamed test-controller.  It is no longer
    packaged or installed by default, because too many users assumed
    incorrectly that ovs-controller was a necessary or desirable part
    of an Open vSwitch deployment.
  - Added vlog option to export to a UDP syslog sink.
  - ovsdb-client:
  * The "monitor" command can now monitor all tables in a database,
    instead of being limited to a single table.
  - The flow-eviction-threshold has been replaced by the flow-limit which is a
    hard limit on the number of flows in the datapath.  It defaults to 200,000
    flows.  OVS automatically adjusts this number depending on network
    conditions.
* Thu Mar 27 2014 dmueller@suse.com
- allow to use kmod as well
* Mon Feb  3 2014 dmueller@suse.com
- another fix in logrotate
* Mon Jan 27 2014 dmueller@suse.com
- fix logrotate configuration
* Tue Jan 21 2014 dmueller@suse.com
- add openvswitch.service for systemd distros
* Tue Jan 14 2014 dmueller@suse.com
- add kernel-312.diff (build against Kernel 3.12.x)
* Fri Jan  3 2014 dmueller@suse.com
- do not build with valgrind-devel on aarch64 (doesn't exist)
* Thu Dec  5 2013 dmueller@suse.com
- update to 2.0.0:
  - The ovs-vswitchd process is no longer single-threaded.  Multiple
    threads are now used to handle flow set up and asynchronous
    logging.
  - OpenFlow:
  * Experimental support for OpenFlow 1.1 (in addition to 1.2 and
    1.3, which had experimental support in 1.10).
  * New support for matching outer source and destination IP address
    of tunneled packets, for tunnel ports configured with the newly
    added "remote_ip=flow" and "local_ip=flow" options.
  * Support for matching on metadata 'pkt_mark' for interacting with
    other system components. On Linux this corresponds to the skb
    mark.
  * Support matching, rewriting SCTP ports
  - The Interface table in the database has a new "ifindex" column to
    report the interface's OS-assigned ifindex.
  - New "check-oftest" Makefile target for running OFTest against Open
    vSwitch.  See README-OFTest for details.
  - The flow eviction threshold has been moved to the Open_vSwitch table.
  - Database names are now mandatory when specifying ovsdb-server options
    through database paths (e.g. Private key option with the database name
    should look like "--private-key=db:Open_vSwitch,SSL,private_key").
  - Added ovs-dev.py, a utility script helpful for Open vSwitch developers.
  - Support for Linux kernels up to 3.10
  - ovs-ofctl:
  * New "ofp-parse" for printing OpenFlow messages read from a file.
  - Added configurable flow caching support to IPFIX exporter.
  - Dropped support for Linux pre-2.6.32.
  - Log file timestamps and ovsdb commit timestamps are now reported
    with millisecond resolution.  (Previous versions only reported
    whole seconds.)
* Wed Dec  4 2013 jsuchome@suse.cz
- added try-restart action to openvswitch-switch init script
  (bnc#849222)
* Wed Nov 20 2013 kmroz@suse.com
- Incorporate ubuntu Linux 3.11 fix to prevent kernel datapath panics.
  Addresses bnc#851395
  + added datapath-add-support-for-linux-3.11.patch
* Tue Oct  1 2013 speilicke@suse.com
- Let openvswitch-switch depend on util-linux instead of uuid-runtime
  (Debian package name). The ovs-ctl / ovs-pki tools use /usr/bin/uuidgen
* Tue Sep 24 2013 bwiedemann@suse.com
- add vlan_apichange.patch to compensate kernel API changes
  between 3.8 and 3.11 in commits f646968f and 86a9bad3
* Fri Sep 13 2013 dmueller@suse.com
- update to 1.11.0:
  * http://openvswitch.org/releases/NEWS-1.11.0
- remove accept-newer-kernel-versions.diff
* Fri Sep 13 2013 dmueller@suse.com
- sign modules for secure boot (bnc#839838)
* Tue Jul  2 2013 tpaszkowski@novell.com
- Build openvswitch kernel module for xen kernel flavor.
* Sun Jun 16 2013 vuntz@suse.com
- Add openvswitch-ipsec.init, Module.supported,
  Module.supported.updates and README.packager as sources: they
  were not listed as such.
- Install openvswitch-ipsec.init if we build ipsec support.
* Thu Jun  6 2013 tpaszkowski@novell.com
- mark openvswitch module shipped with package as supported
* Fri May 17 2013 dmueller@suse.com
- only call boot.sh for newer distros
- build parallel
- accept-newer-kernel-versions.diff:
  Accept newer kernel versions
- sle11-device-ops-backport.diff
  Handle sle11 device ops backport
* Fri May  3 2013 e.istomin@edss.ee
- New upstream version 1.10.0
  http://openvswitch.org/releases/NEWS-1.10.0
- Removed openvswitch-1.7.0-stp-fwd-delay.patch because of bridge compatibility support removing
* Wed Apr  3 2013 tpaszkowski@novell.com
- %%make_install macro no longer works on SLE11. Spec file now uses %%makeinstall.
* Tue Mar 26 2013 speilicke@suse.com
- Use build conditionals instead of %%define and disable GUI by default
  everywhere
* Thu Mar 21 2013 tpaszkowski@novell.com
- Fix openvswitch-controller init script
- Add openflow-controller sysconfig file with default binding to ptcp:
* Tue Mar 12 2013 tpaszkowski@suse.com
- ipsec build temporary disabled
* Fri Mar  8 2013 tpaszkowski@suse.com
- Provides and Obsolete for former openvswitch-common package
* Thu Mar  7 2013 tpaszkowski@suse.com
- always build in openvswitch kernel module (gre tunelling not present
  within the standard kernel module)
- removed unnedded build rquirements (move to appropriate subpackage)
- moved common stuff to main pkg
- added group filed to packages and sub packages
- switch pkg suggest kernel module pkg
- moved python test stuff to python-openvswitch-test sub pkg
- moved ui interface requirements to ovsdbmonitor sub pkg
- ovsdbmonitor will not be build on sles (for now)
- sub pkg test require python-twisted (ovs-test)
- don't call boot.sh on sles11 (old autoconf). Shipped configuration stuff
  is ok (we don't patch plenty of stuff)
- ovs-parse-backtrace now part of main pkg
- addes ovs-l3ping,ovs-vlan-test to test sub pkg
* Thu Feb 28 2013 e.istomin@edss.ee
- New upstream version 1.9.0
  http://openvswitch.org/releases/NEWS-1.9.0
* Thu Nov 15 2012 rhafer@suse.com
- New patch openvswitch-1.7.1-ovs-pki-permissions.patch: Avoid
  creating world writeable directory (bnc#774332, CVE-2012-3449)
* Sun Sep  9 2012 on@morlock.nu
- New upstream version 1.7.1
  * This release only contain bug fixes.
* Tue Jul 31 2012 on@morlock.nu
- New upstream version 1.7.0
  * kernel modules are renamed. openvswitch_mod.ko is now
    openvswitch.ko and brcompat_mod.ko is now brcompat.ko.
  * Increased the number of NXM registers to 8.
  * Added ability to configure DSCP setting for manager and controller
    connections.  By default, these connections have a DSCP value of
    Internetwork Control (0xc0).
  * Added the granular link health statistics, 'cfm_health', to an
    interface.
  * OpenFlow:
  - Added support to mask nd_target for ICMPv6 neighbor discovery flows.
  - Added support for OpenFlow 1.3 port description (OFPMP_PORT_DESC)
    multipart messages.
  * ovs-ofctl:
  - Added the "dump-ports-desc" command to retrieve port
    information using the new port description multipart messages.
  * ovs-test:
  - Added support for spawning ovs-test server from the client.
  - Now ovs-test is able to automatically create test bridges and ports.
  * "ovs-dpctl dump-flows" now prints observed TCP flags in TCP flows.
  * Tripled flow setup performance.
  * The "coverage/log" command previously available through ovs-appctl
    has been replaced by "coverage/show".  The new command replies with
    coverage counter values, instead of logging them.
- Adjusted openvswitch-1.1.0-stp-fwd-delay.patch (new filename)
* Thu Jul 26 2012 rhafer@suse.com
- The kernel modules where renamed in recent kernels. Backported a
  patch from the 1.7 branch to use the new kernel names when
  building on openSUSE > 12.1.
* Tue Jun 26 2012 on@morlock.nu
- New upstream version 1.6.1
  * Added support for bitwise matching on TCP and UDP ports.
  * Support for limiting the number of flows in an OpenFlow flow
    table, with configurable policy for evicting flows upon
    overflow.
  * Added an OpenFlow extension that allows controllers more precise
    control over which messages they receive asynchronously.
  * CFM module CCM broadcasts can now be tagged with an 802.1p priority.
  * Load balancing for bonds can be disabled.
* Wed Jun  6 2012 on@morlock.nu
- New upstream version 1.5.0
  * OpenFlow:
  - Added support for querying, modifying, and deleting flows
    based on flow cookie when using NXM.
  - Added new NXM_PACKET_IN format.
  * ovs-ofctl:
  - Added daemonization support to the monitor and snoop commands.
  * ovs-vsctl:
  - The "find" command supports new set relational operators
    {=}, {!=}, {<}, {>}, {<=}, and {>=}.
  * ovsdb-tool now uses the typical database and schema installation
    directories as defaults.
* Thu May 10 2012 on@morlock.nu
- New upstream version 1.4.1
  * The default MAC learning timeout has been increased from 60 seconds
    to 300 seconds. The MAC learning timeout is now configurable.
  * Bug fixes
* Thu Apr  5 2012 on@morlock.nu
- Build KMP packages from kernel-source on openSuSE > 12.1.
* Tue Mar 13 2012 mvidner@suse.com
- Specify defattr for pki subpackage to fix 11.4 build.
* Thu Mar  1 2012 dmacvicar@suse.de
- Rewrite the package based on the debian version instead
  * current package was tied to xenserver config without
    even requiring it
  * instead of one big package depending even on qt4, there
    are -switch, -controller, -test subpackages now
* Mon Feb 20 2012 on@morlock.nu
- New upstream version 1.4.0
  * Compatible with Open vSwitch kernel module included in Linux 3.3.
  * Don't require the "normal" action to use mirrors.
  * New "VLAN splinters" feature to work around buggy device driver in old Linux versions.
  * Added ability to match ECN and TTL in IPv4 and IPv6 headers.
  * Added ability to match IPv6 flow label.
  * Added ability to modify ECN bits and TTL in IPv4 headers.
  * And many others. See the full change log here:
  http://openvswitch.org/releases/NEWS-1.4.0
* Fri Sep  2 2011 andrea@opensuse.org
- new uopstream version 1.2.1
  * The release only contains bug fixes for the 1.2.0 release
* Mon Aug  8 2011 andrea@opensuse.org
- new upstream version 1.2.0
  * New abstraction layer to make better use of switching ASICs
  * Packaging for Red Hat (RHEL) 5.6 and 6.0
  * Datapath support for Linux kernels up to 3.0
  * And many others.  See the full change log here:
    http://openvswitch.org/releases/ChangeLog-1.2.0
- rebased openvswitch-1.1.0-suse.patch as
  openvswitch-1.2.0-suse.patch to apply to the files
* Thu Jun 23 2011 andrea@opensuse.org
- new upstream version 1.1.1
  * bug fix release
* Wed May 18 2011 andrea@opensuse.org
- re-enabled kmp package since openvswitch_mod.ko and
  brcompat_mod.ko are not available on suse kernel rpms
* Tue May 17 2011 andrea@opensuse.org
- new upstream version 1.1.0 (stable)
- spec file clean up
- added as dependency all python modules to enable additional
  functionalities
- rebase patches
- build pyside support only if pyside is available
* Fri Dec 31 2010 pmullaney@novell.com
- updates for build issues
- fixes for libvirt integration
* Sat Dec 11 2010 pmullaney@novell.com
- initial version 1.1
